package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TAircraftFailure;
import com.amms.system.service.ITAircraftFailureService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 飞机故障及缺陷管理Controller
 * 
 * @author ruoyi
 * @date 2023-12-12
 */
@RestController
@RequestMapping("/Fault/TAircraftFailure")
public class TAircraftFailureController extends BaseController
{
    @Autowired
    private ITAircraftFailureService tAircraftFailureService;

    /**
     * 查询飞机故障及缺陷管理列表
     */
    @PreAuthorize("@ss.hasPermi('Fault:TAircraftFailure:list')")
    @GetMapping("/list")
    public TableDataInfo list(TAircraftFailure tAircraftFailure)
    {
        startPage();
        List<TAircraftFailure> list = tAircraftFailureService.selectTAircraftFailureList(tAircraftFailure);
        return getDataTable(list);
    }

    /**
     * 导出飞机故障及缺陷管理列表
     */
    @PreAuthorize("@ss.hasPermi('Fault:TAircraftFailure:export')")
    @Log(title = "飞机故障及缺陷管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TAircraftFailure tAircraftFailure)
    {
        List<TAircraftFailure> list = tAircraftFailureService.selectTAircraftFailureList(tAircraftFailure);
        ExcelUtil<TAircraftFailure> util = new ExcelUtil<TAircraftFailure>(TAircraftFailure.class);
        util.exportExcel(response, list, "飞机故障及缺陷管理数据");
    }

    /**
     * 获取飞机故障及缺陷管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('Fault:TAircraftFailure:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tAircraftFailureService.selectTAircraftFailureById(id));
    }

    /**
     * 新增飞机故障及缺陷管理
     */
    @PreAuthorize("@ss.hasPermi('Fault:TAircraftFailure:add')")
    @Log(title = "飞机故障及缺陷管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TAircraftFailure tAircraftFailure)
    {
        return toAjax(tAircraftFailureService.insertTAircraftFailure(tAircraftFailure));
    }

    /**
     * 修改飞机故障及缺陷管理
     */
    @PreAuthorize("@ss.hasPermi('Fault:TAircraftFailure:edit')")
    @Log(title = "飞机故障及缺陷管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TAircraftFailure tAircraftFailure)
    {
        return toAjax(tAircraftFailureService.updateTAircraftFailure(tAircraftFailure));
    }

    /**
     * 删除飞机故障及缺陷管理
     */
    @PreAuthorize("@ss.hasPermi('Fault:TAircraftFailure:remove')")
    @Log(title = "飞机故障及缺陷管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tAircraftFailureService.deleteTAircraftFailureByIds(ids));
    }
}
