package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TAssessmentResult;
import com.amms.system.service.ITAssessmentResultService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 考核结果管理Controller
 * 
 * @author ruoyi
 * @date 2023-12-09
 */
@RestController
@RequestMapping("/Train/TAssessmentResult")
public class TAssessmentResultController extends BaseController
{
    @Autowired
    private ITAssessmentResultService tAssessmentResultService;

    /**
     * 查询考核结果管理列表
     */
    @PreAuthorize("@ss.hasPermi('Train:TAssessmentResult:list')")
    @GetMapping("/list")
    public TableDataInfo list(TAssessmentResult tAssessmentResult)
    {
        startPage();
        List<TAssessmentResult> list = tAssessmentResultService.selectTAssessmentResultList(tAssessmentResult);
        return getDataTable(list);
    }

    /**
     * 导出考核结果管理列表
     */
    @PreAuthorize("@ss.hasPermi('Train:TAssessmentResult:export')")
    @Log(title = "考核结果管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TAssessmentResult tAssessmentResult)
    {
        List<TAssessmentResult> list = tAssessmentResultService.selectTAssessmentResultList(tAssessmentResult);
        ExcelUtil<TAssessmentResult> util = new ExcelUtil<TAssessmentResult>(TAssessmentResult.class);
        util.exportExcel(response, list, "考核结果管理数据");
    }

    /**
     * 获取考核结果管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('Train:TAssessmentResult:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tAssessmentResultService.selectTAssessmentResultById(id));
    }

    /**
     * 新增考核结果管理
     */
    @PreAuthorize("@ss.hasPermi('Train:TAssessmentResult:add')")
    @Log(title = "考核结果管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TAssessmentResult tAssessmentResult)
    {
        return toAjax(tAssessmentResultService.insertTAssessmentResult(tAssessmentResult));
    }

    /**
     * 修改考核结果管理
     */
    @PreAuthorize("@ss.hasPermi('Train:TAssessmentResult:edit')")
    @Log(title = "考核结果管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TAssessmentResult tAssessmentResult)
    {
        return toAjax(tAssessmentResultService.updateTAssessmentResult(tAssessmentResult));
    }

    /**
     * 删除考核结果管理
     */
    @PreAuthorize("@ss.hasPermi('Train:TAssessmentResult:remove')")
    @Log(title = "考核结果管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tAssessmentResultService.deleteTAssessmentResultByIds(ids));
    }
}
