package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TBriefingFaultInformation;
import com.amms.system.service.ITBriefingFaultInformationService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 简报故障信息管理Controller
 * 
 * @author ruoyi
 * @date 2023-12-12
 */
@RestController
@RequestMapping("/Fault/TBriefingFaultInformation")
public class TBriefingFaultInformationController extends BaseController
{
    @Autowired
    private ITBriefingFaultInformationService tBriefingFaultInformationService;

    /**
     * 查询简报故障信息管理列表
     */
    @PreAuthorize("@ss.hasPermi('Fault:TBriefingFaultInformation:list')")
    @GetMapping("/list")
    public TableDataInfo list(TBriefingFaultInformation tBriefingFaultInformation)
    {
        startPage();
        List<TBriefingFaultInformation> list = tBriefingFaultInformationService.selectTBriefingFaultInformationList(tBriefingFaultInformation);
        return getDataTable(list);
    }

    /**
     * 导出简报故障信息管理列表
     */
    @PreAuthorize("@ss.hasPermi('Fault:TBriefingFaultInformation:export')")
    @Log(title = "简报故障信息管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TBriefingFaultInformation tBriefingFaultInformation)
    {
        List<TBriefingFaultInformation> list = tBriefingFaultInformationService.selectTBriefingFaultInformationList(tBriefingFaultInformation);
        ExcelUtil<TBriefingFaultInformation> util = new ExcelUtil<TBriefingFaultInformation>(TBriefingFaultInformation.class);
        util.exportExcel(response, list, "简报故障信息管理数据");
    }

    /**
     * 获取简报故障信息管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('Fault:TBriefingFaultInformation:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tBriefingFaultInformationService.selectTBriefingFaultInformationById(id));
    }

    /**
     * 新增简报故障信息管理
     */
    @PreAuthorize("@ss.hasPermi('Fault:TBriefingFaultInformation:add')")
    @Log(title = "简报故障信息管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TBriefingFaultInformation tBriefingFaultInformation)
    {
        return toAjax(tBriefingFaultInformationService.insertTBriefingFaultInformation(tBriefingFaultInformation));
    }

    /**
     * 修改简报故障信息管理
     */
    @PreAuthorize("@ss.hasPermi('Fault:TBriefingFaultInformation:edit')")
    @Log(title = "简报故障信息管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TBriefingFaultInformation tBriefingFaultInformation)
    {
        return toAjax(tBriefingFaultInformationService.updateTBriefingFaultInformation(tBriefingFaultInformation));
    }

    /**
     * 删除简报故障信息管理
     */
    @PreAuthorize("@ss.hasPermi('Fault:TBriefingFaultInformation:remove')")
    @Log(title = "简报故障信息管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tBriefingFaultInformationService.deleteTBriefingFaultInformationByIds(ids));
    }
}
