package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TCommandWorkBill;
import com.amms.system.service.ITCommandWorkBillService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 指令性工作清单管理Controller
 * 
 * @author ruoyi
 * @date 2023-12-08
 */
@RestController
@RequestMapping("/DirectiveTask/TCommandWorkBill")
public class TCommandWorkBillController extends BaseController
{
    @Autowired
    private ITCommandWorkBillService tCommandWorkBillService;

    /**
     * 查询指令性工作清单管理列表
     */
    @PreAuthorize("@ss.hasPermi('DirectiveTask:TCommandWorkBill:list')")
    @GetMapping("/list")
    public TableDataInfo list(TCommandWorkBill tCommandWorkBill)
    {
        startPage();
        List<TCommandWorkBill> list = tCommandWorkBillService.selectTCommandWorkBillList(tCommandWorkBill);
        return getDataTable(list);
    }

    /**
     * 导出指令性工作清单管理列表
     */
    @PreAuthorize("@ss.hasPermi('DirectiveTask:TCommandWorkBill:export')")
    @Log(title = "指令性工作清单管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TCommandWorkBill tCommandWorkBill)
    {
        List<TCommandWorkBill> list = tCommandWorkBillService.selectTCommandWorkBillList(tCommandWorkBill);
        ExcelUtil<TCommandWorkBill> util = new ExcelUtil<TCommandWorkBill>(TCommandWorkBill.class);
        util.exportExcel(response, list, "指令性工作清单管理数据");
    }

    /**
     * 获取指令性工作清单管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('DirectiveTask:TCommandWorkBill:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tCommandWorkBillService.selectTCommandWorkBillById(id));
    }

    /**
     * 新增指令性工作清单管理
     */
    @PreAuthorize("@ss.hasPermi('DirectiveTask:TCommandWorkBill:add')")
    @Log(title = "指令性工作清单管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TCommandWorkBill tCommandWorkBill)
    {
        return toAjax(tCommandWorkBillService.insertTCommandWorkBill(tCommandWorkBill));
    }

    /**
     * 修改指令性工作清单管理
     */
    @PreAuthorize("@ss.hasPermi('DirectiveTask:TCommandWorkBill:edit')")
    @Log(title = "指令性工作清单管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TCommandWorkBill tCommandWorkBill)
    {
        return toAjax(tCommandWorkBillService.updateTCommandWorkBill(tCommandWorkBill));
    }

    /**
     * 删除指令性工作清单管理
     */
    @PreAuthorize("@ss.hasPermi('DirectiveTask:TCommandWorkBill:remove')")
    @Log(title = "指令性工作清单管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tCommandWorkBillService.deleteTCommandWorkBillByIds(ids));
    }
}
