package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TDisclaimerReport;
import com.amms.system.service.ITDisclaimerReportService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 免责报告Controller
 * 
 * @author ruoyi
 * @date 2023-12-09
 */
@RestController
@RequestMapping("/Security/TDisclaimerReport")
public class TDisclaimerReportController extends BaseController
{
    @Autowired
    private ITDisclaimerReportService tDisclaimerReportService;

    /**
     * 查询免责报告列表
     */
    @PreAuthorize("@ss.hasPermi('Security:TDisclaimerReport:list')")
    @GetMapping("/list")
    public TableDataInfo list(TDisclaimerReport tDisclaimerReport)
    {
        startPage();
        List<TDisclaimerReport> list = tDisclaimerReportService.selectTDisclaimerReportList(tDisclaimerReport);
        return getDataTable(list);
    }

    /**
     * 导出免责报告列表
     */
    @PreAuthorize("@ss.hasPermi('Security:TDisclaimerReport:export')")
    @Log(title = "免责报告", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TDisclaimerReport tDisclaimerReport)
    {
        List<TDisclaimerReport> list = tDisclaimerReportService.selectTDisclaimerReportList(tDisclaimerReport);
        ExcelUtil<TDisclaimerReport> util = new ExcelUtil<TDisclaimerReport>(TDisclaimerReport.class);
        util.exportExcel(response, list, "免责报告数据");
    }

    /**
     * 获取免责报告详细信息
     */
    @PreAuthorize("@ss.hasPermi('Security:TDisclaimerReport:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tDisclaimerReportService.selectTDisclaimerReportById(id));
    }

    /**
     * 新增免责报告
     */
    @PreAuthorize("@ss.hasPermi('Security:TDisclaimerReport:add')")
    @Log(title = "免责报告", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TDisclaimerReport tDisclaimerReport)
    {
        return toAjax(tDisclaimerReportService.insertTDisclaimerReport(tDisclaimerReport));
    }

    /**
     * 修改免责报告
     */
    @PreAuthorize("@ss.hasPermi('Security:TDisclaimerReport:edit')")
    @Log(title = "免责报告", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TDisclaimerReport tDisclaimerReport)
    {
        return toAjax(tDisclaimerReportService.updateTDisclaimerReport(tDisclaimerReport));
    }

    /**
     * 删除免责报告
     */
    @PreAuthorize("@ss.hasPermi('Security:TDisclaimerReport:remove')")
    @Log(title = "免责报告", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tDisclaimerReportService.deleteTDisclaimerReportByIds(ids));
    }
}
