package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TElectronicDocument;
import com.amms.system.service.ITElectronicDocumentService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 电子文件管理Controller
 * 
 * @author ruoyi
 * @date 2023-12-12
 */
@RestController
@RequestMapping("/Technicaldata/TElectronicDocument")
public class TElectronicDocumentController extends BaseController
{
    @Autowired
    private ITElectronicDocumentService tElectronicDocumentService;

    /**
     * 查询电子文件管理列表
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TElectronicDocument:list')")
    @GetMapping("/list")
    public TableDataInfo list(TElectronicDocument tElectronicDocument)
    {
        startPage();
        List<TElectronicDocument> list = tElectronicDocumentService.selectTElectronicDocumentList(tElectronicDocument);
        return getDataTable(list);
    }

    /**
     * 导出电子文件管理列表
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TElectronicDocument:export')")
    @Log(title = "电子文件管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TElectronicDocument tElectronicDocument)
    {
        List<TElectronicDocument> list = tElectronicDocumentService.selectTElectronicDocumentList(tElectronicDocument);
        ExcelUtil<TElectronicDocument> util = new ExcelUtil<TElectronicDocument>(TElectronicDocument.class);
        util.exportExcel(response, list, "电子文件管理数据");
    }

    /**
     * 获取电子文件管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TElectronicDocument:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tElectronicDocumentService.selectTElectronicDocumentById(id));
    }

    /**
     * 新增电子文件管理
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TElectronicDocument:add')")
    @Log(title = "电子文件管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TElectronicDocument tElectronicDocument)
    {
        return toAjax(tElectronicDocumentService.insertTElectronicDocument(tElectronicDocument));
    }

    /**
     * 修改电子文件管理
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TElectronicDocument:edit')")
    @Log(title = "电子文件管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TElectronicDocument tElectronicDocument)
    {
        return toAjax(tElectronicDocumentService.updateTElectronicDocument(tElectronicDocument));
    }

    /**
     * 删除电子文件管理
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TElectronicDocument:remove')")
    @Log(title = "电子文件管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tElectronicDocumentService.deleteTElectronicDocumentByIds(ids));
    }
}
