package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TEngineHandover;
import com.amms.system.service.ITEngineHandoverService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 发动机交接管理Controller
 * 
 * @author ruoyi
 * @date 2023-12-12
 */
@RestController
@RequestMapping("/Technicaldata/TEngineHandover")
public class TEngineHandoverController extends BaseController
{
    @Autowired
    private ITEngineHandoverService tEngineHandoverService;

    /**
     * 查询发动机交接管理列表
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TEngineHandover:list')")
    @GetMapping("/list")
    public TableDataInfo list(TEngineHandover tEngineHandover)
    {
        startPage();
        List<TEngineHandover> list = tEngineHandoverService.selectTEngineHandoverList(tEngineHandover);
        return getDataTable(list);
    }

    /**
     * 导出发动机交接管理列表
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TEngineHandover:export')")
    @Log(title = "发动机交接管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TEngineHandover tEngineHandover)
    {
        List<TEngineHandover> list = tEngineHandoverService.selectTEngineHandoverList(tEngineHandover);
        ExcelUtil<TEngineHandover> util = new ExcelUtil<TEngineHandover>(TEngineHandover.class);
        util.exportExcel(response, list, "发动机交接管理数据");
    }

    /**
     * 获取发动机交接管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TEngineHandover:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tEngineHandoverService.selectTEngineHandoverById(id));
    }

    /**
     * 新增发动机交接管理
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TEngineHandover:add')")
    @Log(title = "发动机交接管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TEngineHandover tEngineHandover)
    {
        return toAjax(tEngineHandoverService.insertTEngineHandover(tEngineHandover));
    }

    /**
     * 修改发动机交接管理
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TEngineHandover:edit')")
    @Log(title = "发动机交接管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TEngineHandover tEngineHandover)
    {
        return toAjax(tEngineHandoverService.updateTEngineHandover(tEngineHandover));
    }

    /**
     * 删除发动机交接管理
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TEngineHandover:remove')")
    @Log(title = "发动机交接管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tEngineHandoverService.deleteTEngineHandoverByIds(ids));
    }
}
