package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TEquipmentQuality;
import com.amms.system.service.ITEquipmentQualityService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 装备质量一本账Controller
 * 
 * @author ruoyi
 * @date 2023-12-09
 */
@RestController
@RequestMapping("/Invoice/TEquipmentQuality")
public class TEquipmentQualityController extends BaseController
{
    @Autowired
    private ITEquipmentQualityService tEquipmentQualityService;

    /**
     * 查询装备质量一本账列表
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TEquipmentQuality:list')")
    @GetMapping("/list")
    public TableDataInfo list(TEquipmentQuality tEquipmentQuality)
    {
        startPage();
        List<TEquipmentQuality> list = tEquipmentQualityService.selectTEquipmentQualityList(tEquipmentQuality);
        return getDataTable(list);
    }

    /**
     * 导出装备质量一本账列表
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TEquipmentQuality:export')")
    @Log(title = "装备质量一本账", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TEquipmentQuality tEquipmentQuality)
    {
        List<TEquipmentQuality> list = tEquipmentQualityService.selectTEquipmentQualityList(tEquipmentQuality);
        ExcelUtil<TEquipmentQuality> util = new ExcelUtil<TEquipmentQuality>(TEquipmentQuality.class);
        util.exportExcel(response, list, "装备质量一本账数据");
    }

    /**
     * 获取装备质量一本账详细信息
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TEquipmentQuality:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tEquipmentQualityService.selectTEquipmentQualityById(id));
    }

    /**
     * 新增装备质量一本账
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TEquipmentQuality:add')")
    @Log(title = "装备质量一本账", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TEquipmentQuality tEquipmentQuality)
    {
        return toAjax(tEquipmentQualityService.insertTEquipmentQuality(tEquipmentQuality));
    }

    /**
     * 修改装备质量一本账
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TEquipmentQuality:edit')")
    @Log(title = "装备质量一本账", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TEquipmentQuality tEquipmentQuality)
    {
        return toAjax(tEquipmentQualityService.updateTEquipmentQuality(tEquipmentQuality));
    }

    /**
     * 删除装备质量一本账
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TEquipmentQuality:remove')")
    @Log(title = "装备质量一本账", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tEquipmentQualityService.deleteTEquipmentQualityByIds(ids));
    }
}
