package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TMemorandumManagement;
import com.amms.system.service.ITMemorandumManagementService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 备忘录管理模块Controller
 * 
 * @author ruoyi
 * @date 2023-12-12
 */
@RestController
@RequestMapping("/Technology/TMemorandumManagement")
public class TMemorandumManagementController extends BaseController
{
    @Autowired
    private ITMemorandumManagementService tMemorandumManagementService;

    /**
     * 查询备忘录管理模块列表
     */
    @PreAuthorize("@ss.hasPermi('Technology:TMemorandumManagement:list')")
    @GetMapping("/list")
    public TableDataInfo list(TMemorandumManagement tMemorandumManagement)
    {
        startPage();
        List<TMemorandumManagement> list = tMemorandumManagementService.selectTMemorandumManagementList(tMemorandumManagement);
        return getDataTable(list);
    }

    /**
     * 导出备忘录管理模块列表
     */
    @PreAuthorize("@ss.hasPermi('Technology:TMemorandumManagement:export')")
    @Log(title = "备忘录管理模块", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TMemorandumManagement tMemorandumManagement)
    {
        List<TMemorandumManagement> list = tMemorandumManagementService.selectTMemorandumManagementList(tMemorandumManagement);
        ExcelUtil<TMemorandumManagement> util = new ExcelUtil<TMemorandumManagement>(TMemorandumManagement.class);
        util.exportExcel(response, list, "备忘录管理模块数据");
    }

    /**
     * 获取备忘录管理模块详细信息
     */
    @PreAuthorize("@ss.hasPermi('Technology:TMemorandumManagement:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tMemorandumManagementService.selectTMemorandumManagementById(id));
    }

    /**
     * 新增备忘录管理模块
     */
    @PreAuthorize("@ss.hasPermi('Technology:TMemorandumManagement:add')")
    @Log(title = "备忘录管理模块", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TMemorandumManagement tMemorandumManagement)
    {
        return toAjax(tMemorandumManagementService.insertTMemorandumManagement(tMemorandumManagement));
    }

    /**
     * 修改备忘录管理模块
     */
    @PreAuthorize("@ss.hasPermi('Technology:TMemorandumManagement:edit')")
    @Log(title = "备忘录管理模块", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TMemorandumManagement tMemorandumManagement)
    {
        return toAjax(tMemorandumManagementService.updateTMemorandumManagement(tMemorandumManagement));
    }

    /**
     * 删除备忘录管理模块
     */
    @PreAuthorize("@ss.hasPermi('Technology:TMemorandumManagement:remove')")
    @Log(title = "备忘录管理模块", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tMemorandumManagementService.deleteTMemorandumManagementByIds(ids));
    }
}
