package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TPrepareWar;
import com.amms.system.service.ITPrepareWarService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 备战打仗一本账Controller
 * 
 * @author ruoyi
 * @date 2023-12-09
 */
@RestController
@RequestMapping("/Invoice/TPrepareWar")
public class TPrepareWarController extends BaseController
{
    @Autowired
    private ITPrepareWarService tPrepareWarService;

    /**
     * 查询备战打仗一本账列表
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TPrepareWar:list')")
    @GetMapping("/list")
    public TableDataInfo list(TPrepareWar tPrepareWar)
    {
        startPage();
        List<TPrepareWar> list = tPrepareWarService.selectTPrepareWarList(tPrepareWar);
        return getDataTable(list);
    }

    /**
     * 导出备战打仗一本账列表
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TPrepareWar:export')")
    @Log(title = "备战打仗一本账", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TPrepareWar tPrepareWar)
    {
        List<TPrepareWar> list = tPrepareWarService.selectTPrepareWarList(tPrepareWar);
        ExcelUtil<TPrepareWar> util = new ExcelUtil<TPrepareWar>(TPrepareWar.class);
        util.exportExcel(response, list, "备战打仗一本账数据");
    }

    /**
     * 获取备战打仗一本账详细信息
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TPrepareWar:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tPrepareWarService.selectTPrepareWarById(id));
    }

    /**
     * 新增备战打仗一本账
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TPrepareWar:add')")
    @Log(title = "备战打仗一本账", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TPrepareWar tPrepareWar)
    {
        return toAjax(tPrepareWarService.insertTPrepareWar(tPrepareWar));
    }

    /**
     * 修改备战打仗一本账
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TPrepareWar:edit')")
    @Log(title = "备战打仗一本账", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TPrepareWar tPrepareWar)
    {
        return toAjax(tPrepareWarService.updateTPrepareWar(tPrepareWar));
    }

    /**
     * 删除备战打仗一本账
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TPrepareWar:remove')")
    @Log(title = "备战打仗一本账", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tPrepareWarService.deleteTPrepareWarByIds(ids));
    }
}
