package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TSafetyInspection;
import com.amms.system.service.ITSafetyInspectionService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 安全检查信息Controller
 * 
 * @author ruoyi
 * @date 2023-12-09
 */
@RestController
@RequestMapping("/Security/TSafetyInspection")
public class TSafetyInspectionController extends BaseController
{
    @Autowired
    private ITSafetyInspectionService tSafetyInspectionService;

    /**
     * 查询安全检查信息列表
     */
    @PreAuthorize("@ss.hasPermi('Security:TSafetyInspection:list')")
    @GetMapping("/list")
    public TableDataInfo list(TSafetyInspection tSafetyInspection)
    {
        startPage();
        List<TSafetyInspection> list = tSafetyInspectionService.selectTSafetyInspectionList(tSafetyInspection);
        return getDataTable(list);
    }

    /**
     * 导出安全检查信息列表
     */
    @PreAuthorize("@ss.hasPermi('Security:TSafetyInspection:export')")
    @Log(title = "安全检查信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TSafetyInspection tSafetyInspection)
    {
        List<TSafetyInspection> list = tSafetyInspectionService.selectTSafetyInspectionList(tSafetyInspection);
        ExcelUtil<TSafetyInspection> util = new ExcelUtil<TSafetyInspection>(TSafetyInspection.class);
        util.exportExcel(response, list, "安全检查信息数据");
    }

    /**
     * 获取安全检查信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('Security:TSafetyInspection:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tSafetyInspectionService.selectTSafetyInspectionById(id));
    }

    /**
     * 新增安全检查信息
     */
    @PreAuthorize("@ss.hasPermi('Security:TSafetyInspection:add')")
    @Log(title = "安全检查信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TSafetyInspection tSafetyInspection)
    {
        return toAjax(tSafetyInspectionService.insertTSafetyInspection(tSafetyInspection));
    }

    /**
     * 修改安全检查信息
     */
    @PreAuthorize("@ss.hasPermi('Security:TSafetyInspection:edit')")
    @Log(title = "安全检查信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TSafetyInspection tSafetyInspection)
    {
        return toAjax(tSafetyInspectionService.updateTSafetyInspection(tSafetyInspection));
    }

    /**
     * 删除安全检查信息
     */
    @PreAuthorize("@ss.hasPermi('Security:TSafetyInspection:remove')")
    @Log(title = "安全检查信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tSafetyInspectionService.deleteTSafetyInspectionByIds(ids));
    }
}
