package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TSafetyReward;
import com.amms.system.service.ITSafetyRewardService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 安全奖惩信息Controller
 * 
 * @author ruoyi
 * @date 2023-12-09
 */
@RestController
@RequestMapping("/Security/TSafetyReward")
public class TSafetyRewardController extends BaseController
{
    @Autowired
    private ITSafetyRewardService tSafetyRewardService;

    /**
     * 查询安全奖惩信息列表
     */
    @PreAuthorize("@ss.hasPermi('Security:TSafetyReward:list')")
    @GetMapping("/list")
    public TableDataInfo list(TSafetyReward tSafetyReward)
    {
        startPage();
        List<TSafetyReward> list = tSafetyRewardService.selectTSafetyRewardList(tSafetyReward);
        return getDataTable(list);
    }

    /**
     * 导出安全奖惩信息列表
     */
    @PreAuthorize("@ss.hasPermi('Security:TSafetyReward:export')")
    @Log(title = "安全奖惩信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TSafetyReward tSafetyReward)
    {
        List<TSafetyReward> list = tSafetyRewardService.selectTSafetyRewardList(tSafetyReward);
        ExcelUtil<TSafetyReward> util = new ExcelUtil<TSafetyReward>(TSafetyReward.class);
        util.exportExcel(response, list, "安全奖惩信息数据");
    }

    /**
     * 获取安全奖惩信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('Security:TSafetyReward:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tSafetyRewardService.selectTSafetyRewardById(id));
    }

    /**
     * 新增安全奖惩信息
     */
    @PreAuthorize("@ss.hasPermi('Security:TSafetyReward:add')")
    @Log(title = "安全奖惩信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TSafetyReward tSafetyReward)
    {
        return toAjax(tSafetyRewardService.insertTSafetyReward(tSafetyReward));
    }

    /**
     * 修改安全奖惩信息
     */
    @PreAuthorize("@ss.hasPermi('Security:TSafetyReward:edit')")
    @Log(title = "安全奖惩信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TSafetyReward tSafetyReward)
    {
        return toAjax(tSafetyRewardService.updateTSafetyReward(tSafetyReward));
    }

    /**
     * 删除安全奖惩信息
     */
    @PreAuthorize("@ss.hasPermi('Security:TSafetyReward:remove')")
    @Log(title = "安全奖惩信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tSafetyRewardService.deleteTSafetyRewardByIds(ids));
    }
}
