package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TSoftwareVersion;
import com.amms.system.service.ITSoftwareVersionService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 软件版本管理模块Controller
 * 
 * @author ruoyi
 * @date 2023-12-12
 */
@RestController
@RequestMapping("/Technology/TSoftwareVersion")
public class TSoftwareVersionController extends BaseController
{
    @Autowired
    private ITSoftwareVersionService tSoftwareVersionService;

    /**
     * 查询软件版本管理模块列表
     */
    @PreAuthorize("@ss.hasPermi('Technology:TSoftwareVersion:list')")
    @GetMapping("/list")
    public TableDataInfo list(TSoftwareVersion tSoftwareVersion)
    {
        startPage();
        List<TSoftwareVersion> list = tSoftwareVersionService.selectTSoftwareVersionList(tSoftwareVersion);
        return getDataTable(list);
    }

    /**
     * 导出软件版本管理模块列表
     */
    @PreAuthorize("@ss.hasPermi('Technology:TSoftwareVersion:export')")
    @Log(title = "软件版本管理模块", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TSoftwareVersion tSoftwareVersion)
    {
        List<TSoftwareVersion> list = tSoftwareVersionService.selectTSoftwareVersionList(tSoftwareVersion);
        ExcelUtil<TSoftwareVersion> util = new ExcelUtil<TSoftwareVersion>(TSoftwareVersion.class);
        util.exportExcel(response, list, "软件版本管理模块数据");
    }

    /**
     * 获取软件版本管理模块详细信息
     */
    @PreAuthorize("@ss.hasPermi('Technology:TSoftwareVersion:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tSoftwareVersionService.selectTSoftwareVersionById(id));
    }

    /**
     * 新增软件版本管理模块
     */
    @PreAuthorize("@ss.hasPermi('Technology:TSoftwareVersion:add')")
    @Log(title = "软件版本管理模块", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TSoftwareVersion tSoftwareVersion)
    {
        return toAjax(tSoftwareVersionService.insertTSoftwareVersion(tSoftwareVersion));
    }

    /**
     * 修改软件版本管理模块
     */
    @PreAuthorize("@ss.hasPermi('Technology:TSoftwareVersion:edit')")
    @Log(title = "软件版本管理模块", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TSoftwareVersion tSoftwareVersion)
    {
        return toAjax(tSoftwareVersionService.updateTSoftwareVersion(tSoftwareVersion));
    }

    /**
     * 删除软件版本管理模块
     */
    @PreAuthorize("@ss.hasPermi('Technology:TSoftwareVersion:remove')")
    @Log(title = "软件版本管理模块", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tSoftwareVersionService.deleteTSoftwareVersionByIds(ids));
    }
}
