package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TTechnicalBulletin;
import com.amms.system.service.ITTechnicalBulletinService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 技术通报管理模块Controller
 * 
 * @author ruoyi
 * @date 2023-12-12
 */
@RestController
@RequestMapping("/Technology/TTechnicalBulletin")
public class TTechnicalBulletinController extends BaseController
{
    @Autowired
    private ITTechnicalBulletinService tTechnicalBulletinService;

    /**
     * 查询技术通报管理模块列表
     */
    @PreAuthorize("@ss.hasPermi('Technology:TTechnicalBulletin:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTechnicalBulletin tTechnicalBulletin)
    {
        startPage();
        List<TTechnicalBulletin> list = tTechnicalBulletinService.selectTTechnicalBulletinList(tTechnicalBulletin);
        return getDataTable(list);
    }

    /**
     * 导出技术通报管理模块列表
     */
    @PreAuthorize("@ss.hasPermi('Technology:TTechnicalBulletin:export')")
    @Log(title = "技术通报管理模块", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TTechnicalBulletin tTechnicalBulletin)
    {
        List<TTechnicalBulletin> list = tTechnicalBulletinService.selectTTechnicalBulletinList(tTechnicalBulletin);
        ExcelUtil<TTechnicalBulletin> util = new ExcelUtil<TTechnicalBulletin>(TTechnicalBulletin.class);
        util.exportExcel(response, list, "技术通报管理模块数据");
    }

    /**
     * 获取技术通报管理模块详细信息
     */
    @PreAuthorize("@ss.hasPermi('Technology:TTechnicalBulletin:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tTechnicalBulletinService.selectTTechnicalBulletinById(id));
    }

    /**
     * 新增技术通报管理模块
     */
    @PreAuthorize("@ss.hasPermi('Technology:TTechnicalBulletin:add')")
    @Log(title = "技术通报管理模块", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTechnicalBulletin tTechnicalBulletin)
    {
        return toAjax(tTechnicalBulletinService.insertTTechnicalBulletin(tTechnicalBulletin));
    }

    /**
     * 修改技术通报管理模块
     */
    @PreAuthorize("@ss.hasPermi('Technology:TTechnicalBulletin:edit')")
    @Log(title = "技术通报管理模块", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTechnicalBulletin tTechnicalBulletin)
    {
        return toAjax(tTechnicalBulletinService.updateTTechnicalBulletin(tTechnicalBulletin));
    }

    /**
     * 删除技术通报管理模块
     */
    @PreAuthorize("@ss.hasPermi('Technology:TTechnicalBulletin:remove')")
    @Log(title = "技术通报管理模块", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTechnicalBulletinService.deleteTTechnicalBulletinByIds(ids));
    }
}
