package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TTechnicalChanges;
import com.amms.system.service.ITTechnicalChangesService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 技术更改单管理模块Controller
 * 
 * @author ruoyi
 * @date 2023-12-12
 */
@RestController
@RequestMapping("/Technology/TTechnicalChanges")
public class TTechnicalChangesController extends BaseController
{
    @Autowired
    private ITTechnicalChangesService tTechnicalChangesService;

    /**
     * 查询技术更改单管理模块列表
     */
    @PreAuthorize("@ss.hasPermi('Technology:TTechnicalChanges:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTechnicalChanges tTechnicalChanges)
    {
        startPage();
        List<TTechnicalChanges> list = tTechnicalChangesService.selectTTechnicalChangesList(tTechnicalChanges);
        return getDataTable(list);
    }

    /**
     * 导出技术更改单管理模块列表
     */
    @PreAuthorize("@ss.hasPermi('Technology:TTechnicalChanges:export')")
    @Log(title = "技术更改单管理模块", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TTechnicalChanges tTechnicalChanges)
    {
        List<TTechnicalChanges> list = tTechnicalChangesService.selectTTechnicalChangesList(tTechnicalChanges);
        ExcelUtil<TTechnicalChanges> util = new ExcelUtil<TTechnicalChanges>(TTechnicalChanges.class);
        util.exportExcel(response, list, "技术更改单管理模块数据");
    }

    /**
     * 获取技术更改单管理模块详细信息
     */
    @PreAuthorize("@ss.hasPermi('Technology:TTechnicalChanges:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tTechnicalChangesService.selectTTechnicalChangesById(id));
    }

    /**
     * 新增技术更改单管理模块
     */
    @PreAuthorize("@ss.hasPermi('Technology:TTechnicalChanges:add')")
    @Log(title = "技术更改单管理模块", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTechnicalChanges tTechnicalChanges)
    {
        return toAjax(tTechnicalChangesService.insertTTechnicalChanges(tTechnicalChanges));
    }

    /**
     * 修改技术更改单管理模块
     */
    @PreAuthorize("@ss.hasPermi('Technology:TTechnicalChanges:edit')")
    @Log(title = "技术更改单管理模块", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTechnicalChanges tTechnicalChanges)
    {
        return toAjax(tTechnicalChangesService.updateTTechnicalChanges(tTechnicalChanges));
    }

    /**
     * 删除技术更改单管理模块
     */
    @PreAuthorize("@ss.hasPermi('Technology:TTechnicalChanges:remove')")
    @Log(title = "技术更改单管理模块", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTechnicalChangesService.deleteTTechnicalChangesByIds(ids));
    }
}
