package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TTechnicalData;
import com.amms.system.service.ITTechnicalDataService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 技术资料管理Controller
 * 
 * @author ruoyi
 * @date 2023-12-12
 */
@RestController
@RequestMapping("/Technicaldata/TTechnicalData")
public class TTechnicalDataController extends BaseController
{
    @Autowired
    private ITTechnicalDataService tTechnicalDataService;

    /**
     * 查询技术资料管理列表
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TTechnicalData:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTechnicalData tTechnicalData)
    {
        startPage();
        List<TTechnicalData> list = tTechnicalDataService.selectTTechnicalDataList(tTechnicalData);
        return getDataTable(list);
    }

    /**
     * 导出技术资料管理列表
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TTechnicalData:export')")
    @Log(title = "技术资料管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TTechnicalData tTechnicalData)
    {
        List<TTechnicalData> list = tTechnicalDataService.selectTTechnicalDataList(tTechnicalData);
        ExcelUtil<TTechnicalData> util = new ExcelUtil<TTechnicalData>(TTechnicalData.class);
        util.exportExcel(response, list, "技术资料管理数据");
    }

    /**
     * 获取技术资料管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TTechnicalData:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tTechnicalDataService.selectTTechnicalDataById(id));
    }

    /**
     * 新增技术资料管理
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TTechnicalData:add')")
    @Log(title = "技术资料管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTechnicalData tTechnicalData)
    {
        return toAjax(tTechnicalDataService.insertTTechnicalData(tTechnicalData));
    }

    /**
     * 修改技术资料管理
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TTechnicalData:edit')")
    @Log(title = "技术资料管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTechnicalData tTechnicalData)
    {
        return toAjax(tTechnicalDataService.updateTTechnicalData(tTechnicalData));
    }

    /**
     * 删除技术资料管理
     */
    @PreAuthorize("@ss.hasPermi('Technicaldata:TTechnicalData:remove')")
    @Log(title = "技术资料管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTechnicalDataService.deleteTTechnicalDataByIds(ids));
    }
}
