package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TTodayInHistory;
import com.amms.system.service.ITTodayInHistoryService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 历史上的今天Controller
 * 
 * @author ruoyi
 * @date 2023-12-09
 */
@RestController
@RequestMapping("/Security/TTodayInHistory")
public class TTodayInHistoryController extends BaseController
{
    @Autowired
    private ITTodayInHistoryService tTodayInHistoryService;

    /**
     * 查询历史上的今天列表
     */
    @PreAuthorize("@ss.hasPermi('Security:TTodayInHistory:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTodayInHistory tTodayInHistory)
    {
        startPage();
        List<TTodayInHistory> list = tTodayInHistoryService.selectTTodayInHistoryList(tTodayInHistory);
        return getDataTable(list);
    }

    /**
     * 导出历史上的今天列表
     */
    @PreAuthorize("@ss.hasPermi('Security:TTodayInHistory:export')")
    @Log(title = "历史上的今天", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TTodayInHistory tTodayInHistory)
    {
        List<TTodayInHistory> list = tTodayInHistoryService.selectTTodayInHistoryList(tTodayInHistory);
        ExcelUtil<TTodayInHistory> util = new ExcelUtil<TTodayInHistory>(TTodayInHistory.class);
        util.exportExcel(response, list, "历史上的今天数据");
    }

    /**
     * 获取历史上的今天详细信息
     */
    @PreAuthorize("@ss.hasPermi('Security:TTodayInHistory:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tTodayInHistoryService.selectTTodayInHistoryById(id));
    }

    /**
     * 新增历史上的今天
     */
    @PreAuthorize("@ss.hasPermi('Security:TTodayInHistory:add')")
    @Log(title = "历史上的今天", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTodayInHistory tTodayInHistory)
    {
        return toAjax(tTodayInHistoryService.insertTTodayInHistory(tTodayInHistory));
    }

    /**
     * 修改历史上的今天
     */
    @PreAuthorize("@ss.hasPermi('Security:TTodayInHistory:edit')")
    @Log(title = "历史上的今天", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTodayInHistory tTodayInHistory)
    {
        return toAjax(tTodayInHistoryService.updateTTodayInHistory(tTodayInHistory));
    }

    /**
     * 删除历史上的今天
     */
    @PreAuthorize("@ss.hasPermi('Security:TTodayInHistory:remove')")
    @Log(title = "历史上的今天", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTodayInHistoryService.deleteTTodayInHistoryByIds(ids));
    }
}
