package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TTrainingManagement;
import com.amms.system.service.ITTrainingManagementService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 人员训练技术档案管理Controller
 * 
 * @author ruoyi
 * @date 2023-12-09
 */
@RestController
@RequestMapping("/Train/TTrainingManagement")
public class TTrainingManagementController extends BaseController
{
    @Autowired
    private ITTrainingManagementService tTrainingManagementService;

    /**
     * 查询人员训练技术档案管理列表
     */
    @PreAuthorize("@ss.hasPermi('Train:TTrainingManagement:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTrainingManagement tTrainingManagement)
    {
        startPage();
        List<TTrainingManagement> list = tTrainingManagementService.selectTTrainingManagementList(tTrainingManagement);
        return getDataTable(list);
    }

    /**
     * 导出人员训练技术档案管理列表
     */
    @PreAuthorize("@ss.hasPermi('Train:TTrainingManagement:export')")
    @Log(title = "人员训练技术档案管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TTrainingManagement tTrainingManagement)
    {
        List<TTrainingManagement> list = tTrainingManagementService.selectTTrainingManagementList(tTrainingManagement);
        ExcelUtil<TTrainingManagement> util = new ExcelUtil<TTrainingManagement>(TTrainingManagement.class);
        util.exportExcel(response, list, "人员训练技术档案管理数据");
    }

    /**
     * 获取人员训练技术档案管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('Train:TTrainingManagement:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tTrainingManagementService.selectTTrainingManagementById(id));
    }

    /**
     * 新增人员训练技术档案管理
     */
    @PreAuthorize("@ss.hasPermi('Train:TTrainingManagement:add')")
    @Log(title = "人员训练技术档案管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTrainingManagement tTrainingManagement)
    {
        return toAjax(tTrainingManagementService.insertTTrainingManagement(tTrainingManagement));
    }

    /**
     * 修改人员训练技术档案管理
     */
    @PreAuthorize("@ss.hasPermi('Train:TTrainingManagement:edit')")
    @Log(title = "人员训练技术档案管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTrainingManagement tTrainingManagement)
    {
        return toAjax(tTrainingManagementService.updateTTrainingManagement(tTrainingManagement));
    }

    /**
     * 删除人员训练技术档案管理
     */
    @PreAuthorize("@ss.hasPermi('Train:TTrainingManagement:remove')")
    @Log(title = "人员训练技术档案管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTrainingManagementService.deleteTTrainingManagementByIds(ids));
    }
}
