package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TTroopProblem;
import com.amms.system.service.ITTroopProblemService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 部队问题一本账Controller
 * 
 * @author ruoyi
 * @date 2023-12-09
 */
@RestController
@RequestMapping("/Invoice/TTroopProblem")
public class TTroopProblemController extends BaseController
{
    @Autowired
    private ITTroopProblemService tTroopProblemService;

    /**
     * 查询部队问题一本账列表
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TTroopProblem:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTroopProblem tTroopProblem)
    {
        startPage();
        List<TTroopProblem> list = tTroopProblemService.selectTTroopProblemList(tTroopProblem);
        return getDataTable(list);
    }

    /**
     * 导出部队问题一本账列表
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TTroopProblem:export')")
    @Log(title = "部队问题一本账", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TTroopProblem tTroopProblem)
    {
        List<TTroopProblem> list = tTroopProblemService.selectTTroopProblemList(tTroopProblem);
        ExcelUtil<TTroopProblem> util = new ExcelUtil<TTroopProblem>(TTroopProblem.class);
        util.exportExcel(response, list, "部队问题一本账数据");
    }

    /**
     * 获取部队问题一本账详细信息
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TTroopProblem:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tTroopProblemService.selectTTroopProblemById(id));
    }

    /**
     * 新增部队问题一本账
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TTroopProblem:add')")
    @Log(title = "部队问题一本账", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTroopProblem tTroopProblem)
    {
        return toAjax(tTroopProblemService.insertTTroopProblem(tTroopProblem));
    }

    /**
     * 修改部队问题一本账
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TTroopProblem:edit')")
    @Log(title = "部队问题一本账", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTroopProblem tTroopProblem)
    {
        return toAjax(tTroopProblemService.updateTTroopProblem(tTroopProblem));
    }

    /**
     * 删除部队问题一本账
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TTroopProblem:remove')")
    @Log(title = "部队问题一本账", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTroopProblemService.deleteTTroopProblemByIds(ids));
    }
}
