package com.amms.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.amms.common.annotation.Log;
import com.amms.common.core.controller.BaseController;
import com.amms.common.core.domain.AjaxResult;
import com.amms.common.enums.BusinessType;
import com.amms.system.domain.TWorkPlan;
import com.amms.system.service.ITWorkPlanService;
import com.amms.common.utils.poi.ExcelUtil;
import com.amms.common.core.page.TableDataInfo;

/**
 * 工作计划一本账Controller
 * 
 * @author ruoyi
 * @date 2023-12-09
 */
@RestController
@RequestMapping("/Invoice/TWorkPlan")
public class TWorkPlanController extends BaseController
{
    @Autowired
    private ITWorkPlanService tWorkPlanService;

    /**
     * 查询工作计划一本账列表
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TWorkPlan:list')")
    @GetMapping("/list")
    public TableDataInfo list(TWorkPlan tWorkPlan)
    {
        startPage();
        List<TWorkPlan> list = tWorkPlanService.selectTWorkPlanList(tWorkPlan);
        return getDataTable(list);
    }

    /**
     * 导出工作计划一本账列表
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TWorkPlan:export')")
    @Log(title = "工作计划一本账", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TWorkPlan tWorkPlan)
    {
        List<TWorkPlan> list = tWorkPlanService.selectTWorkPlanList(tWorkPlan);
        ExcelUtil<TWorkPlan> util = new ExcelUtil<TWorkPlan>(TWorkPlan.class);
        util.exportExcel(response, list, "工作计划一本账数据");
    }

    /**
     * 获取工作计划一本账详细信息
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TWorkPlan:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tWorkPlanService.selectTWorkPlanById(id));
    }

    /**
     * 新增工作计划一本账
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TWorkPlan:add')")
    @Log(title = "工作计划一本账", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TWorkPlan tWorkPlan)
    {
        return toAjax(tWorkPlanService.insertTWorkPlan(tWorkPlan));
    }

    /**
     * 修改工作计划一本账
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TWorkPlan:edit')")
    @Log(title = "工作计划一本账", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TWorkPlan tWorkPlan)
    {
        return toAjax(tWorkPlanService.updateTWorkPlan(tWorkPlan));
    }

    /**
     * 删除工作计划一本账
     */
    @PreAuthorize("@ss.hasPermi('Invoice:TWorkPlan:remove')")
    @Log(title = "工作计划一本账", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tWorkPlanService.deleteTWorkPlanByIds(ids));
    }
}
