package com.amms.system.service.impl;

import java.util.List;
import com.amms.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.amms.system.mapper.TSafetyInspectionMapper;
import com.amms.system.domain.TSafetyInspection;
import com.amms.system.service.ITSafetyInspectionService;

/**
 * 安全检查信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-12-09
 */
@Service
public class TSafetyInspectionServiceImpl implements ITSafetyInspectionService 
{
    @Autowired
    private TSafetyInspectionMapper tSafetyInspectionMapper;

    /**
     * 查询安全检查信息
     * 
     * @param id 安全检查信息主键
     * @return 安全检查信息
     */
    @Override
    public TSafetyInspection selectTSafetyInspectionById(Long id)
    {
        return tSafetyInspectionMapper.selectTSafetyInspectionById(id);
    }

    /**
     * 查询安全检查信息列表
     * 
     * @param tSafetyInspection 安全检查信息
     * @return 安全检查信息
     */
    @Override
    public List<TSafetyInspection> selectTSafetyInspectionList(TSafetyInspection tSafetyInspection)
    {
        return tSafetyInspectionMapper.selectTSafetyInspectionList(tSafetyInspection);
    }

    /**
     * 新增安全检查信息
     * 
     * @param tSafetyInspection 安全检查信息
     * @return 结果
     */
    @Override
    public int insertTSafetyInspection(TSafetyInspection tSafetyInspection)
    {
        tSafetyInspection.setCreateTime(DateUtils.getNowDate());
        return tSafetyInspectionMapper.insertTSafetyInspection(tSafetyInspection);
    }

    /**
     * 修改安全检查信息
     * 
     * @param tSafetyInspection 安全检查信息
     * @return 结果
     */
    @Override
    public int updateTSafetyInspection(TSafetyInspection tSafetyInspection)
    {
        tSafetyInspection.setUpdateTime(DateUtils.getNowDate());
        return tSafetyInspectionMapper.updateTSafetyInspection(tSafetyInspection);
    }

    /**
     * 批量删除安全检查信息
     * 
     * @param ids 需要删除的安全检查信息主键
     * @return 结果
     */
    @Override
    public int deleteTSafetyInspectionByIds(Long[] ids)
    {
        return tSafetyInspectionMapper.deleteTSafetyInspectionByIds(ids);
    }

    /**
     * 删除安全检查信息信息
     * 
     * @param id 安全检查信息主键
     * @return 结果
     */
    @Override
    public int deleteTSafetyInspectionById(Long id)
    {
        return tSafetyInspectionMapper.deleteTSafetyInspectionById(id);
    }
}
