package com.amms.system.service.impl;

import java.util.List;
import com.amms.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.amms.system.mapper.TSafetyRewardMapper;
import com.amms.system.domain.TSafetyReward;
import com.amms.system.service.ITSafetyRewardService;

/**
 * 安全奖惩信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-12-09
 */
@Service
public class TSafetyRewardServiceImpl implements ITSafetyRewardService 
{
    @Autowired
    private TSafetyRewardMapper tSafetyRewardMapper;

    /**
     * 查询安全奖惩信息
     * 
     * @param id 安全奖惩信息主键
     * @return 安全奖惩信息
     */
    @Override
    public TSafetyReward selectTSafetyRewardById(Long id)
    {
        return tSafetyRewardMapper.selectTSafetyRewardById(id);
    }

    /**
     * 查询安全奖惩信息列表
     * 
     * @param tSafetyReward 安全奖惩信息
     * @return 安全奖惩信息
     */
    @Override
    public List<TSafetyReward> selectTSafetyRewardList(TSafetyReward tSafetyReward)
    {
        return tSafetyRewardMapper.selectTSafetyRewardList(tSafetyReward);
    }

    /**
     * 新增安全奖惩信息
     * 
     * @param tSafetyReward 安全奖惩信息
     * @return 结果
     */
    @Override
    public int insertTSafetyReward(TSafetyReward tSafetyReward)
    {
        tSafetyReward.setCreateTime(DateUtils.getNowDate());
        return tSafetyRewardMapper.insertTSafetyReward(tSafetyReward);
    }

    /**
     * 修改安全奖惩信息
     * 
     * @param tSafetyReward 安全奖惩信息
     * @return 结果
     */
    @Override
    public int updateTSafetyReward(TSafetyReward tSafetyReward)
    {
        tSafetyReward.setUpdateTime(DateUtils.getNowDate());
        return tSafetyRewardMapper.updateTSafetyReward(tSafetyReward);
    }

    /**
     * 批量删除安全奖惩信息
     * 
     * @param ids 需要删除的安全奖惩信息主键
     * @return 结果
     */
    @Override
    public int deleteTSafetyRewardByIds(Long[] ids)
    {
        return tSafetyRewardMapper.deleteTSafetyRewardByIds(ids);
    }

    /**
     * 删除安全奖惩信息信息
     * 
     * @param id 安全奖惩信息主键
     * @return 结果
     */
    @Override
    public int deleteTSafetyRewardById(Long id)
    {
        return tSafetyRewardMapper.deleteTSafetyRewardById(id);
    }
}
