-- ----------------------------
-- 1、部门表
-- ----------------------------
drop table if exists sys_dept;
create table sys_dept (
  dept_id           bigint(20)      not null auto_increment    comment '部门id',
  parent_id         bigint(20)      default 0                  comment '父部门id',
  ancestors         varchar(50)     default ''                 comment '祖级列表',
  dept_name         varchar(30)     default ''                 comment '部门名称',
  order_num         int(4)          default 0                  comment '显示顺序',
  leader            varchar(20)     default null               comment '负责人',
  phone             varchar(11)     default null               comment '联系电话',
  email             varchar(50)     default null               comment '邮箱',
  status            char(1)         default '0'                comment '部门状态（0正常 1停用）',
  del_flag          char(1)         default '0'                comment '删除标志（0代表存在 2代表删除）',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time 	    datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  primary key (dept_id)
) engine=innodb auto_increment=200 comment = '部门表';

-- ----------------------------
-- 初始化-部门表数据
-- ----------------------------
insert into sys_dept values(100,  0,   '0',          '若依科技',   0, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', sysdate(), '', null);
insert into sys_dept values(101,  100, '0,100',      '深圳总公司', 1, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', sysdate(), '', null);
insert into sys_dept values(102,  100, '0,100',      '长沙分公司', 2, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', sysdate(), '', null);
insert into sys_dept values(103,  101, '0,100,101',  '研发部门',   1, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', sysdate(), '', null);
insert into sys_dept values(104,  101, '0,100,101',  '市场部门',   2, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', sysdate(), '', null);
insert into sys_dept values(105,  101, '0,100,101',  '测试部门',   3, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', sysdate(), '', null);
insert into sys_dept values(106,  101, '0,100,101',  '财务部门',   4, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', sysdate(), '', null);
insert into sys_dept values(107,  101, '0,100,101',  '运维部门',   5, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', sysdate(), '', null);
insert into sys_dept values(108,  102, '0,100,102',  '市场部门',   1, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', sysdate(), '', null);
insert into sys_dept values(109,  102, '0,100,102',  '财务部门',   2, '若依', '15888888888', 'ry@qq.com', '0', '0', 'admin', sysdate(), '', null);


-- ----------------------------
-- 2、用户信息表
-- ----------------------------
drop table if exists sys_user;
create table sys_user (
  user_id           bigint(20)      not null auto_increment    comment '用户ID',
  dept_id           bigint(20)      default null               comment '部门ID',
  user_name         varchar(30)     not null                   comment '用户账号',
  nick_name         varchar(30)     not null                   comment '用户昵称',
  user_type         varchar(2)      default '00'               comment '用户类型（00系统用户）',
  email             varchar(50)     default ''                 comment '用户邮箱',
  phonenumber       varchar(11)     default ''                 comment '手机号码',
  sex               char(1)         default '0'                comment '用户性别（0男 1女 2未知）',
  avatar            varchar(100)    default ''                 comment '头像地址',
  password          varchar(100)    default ''                 comment '密码',
  status            char(1)         default '0'                comment '帐号状态（0正常 1停用）',
  del_flag          char(1)         default '0'                comment '删除标志（0代表存在 2代表删除）',
  login_ip          varchar(128)    default ''                 comment '最后登录IP',
  login_date        datetime                                   comment '最后登录时间',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time       datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  remark            varchar(500)    default null               comment '备注',
  primary key (user_id)
) engine=innodb auto_increment=100 comment = '用户信息表';

-- ----------------------------
-- 初始化-用户信息表数据
-- ----------------------------
insert into sys_user values(1,  103, 'admin', '若依', '00', 'ry@163.com', '15888888888', '1', '', '$2a$10$7JB720yubVSZvUI0rEqK/.VqGOZTH.ulu33dHOiBE8ByOhJIrdAu2', '0', '0', '127.0.0.1', sysdate(), 'admin', sysdate(), '', null, '管理员');
insert into sys_user values(2,  105, 'ry',    '若依', '00', 'ry@qq.com',  '15666666666', '1', '', '$2a$10$7JB720yubVSZvUI0rEqK/.VqGOZTH.ulu33dHOiBE8ByOhJIrdAu2', '0', '0', '127.0.0.1', sysdate(), 'admin', sysdate(), '', null, '测试员');


-- ----------------------------
-- 3、岗位信息表
-- ----------------------------
drop table if exists sys_post;
create table sys_post
(
  post_id       bigint(20)      not null auto_increment    comment '岗位ID',
  post_code     varchar(64)     not null                   comment '岗位编码',
  post_name     varchar(50)     not null                   comment '岗位名称',
  post_sort     int(4)          not null                   comment '显示顺序',
  status        char(1)         not null                   comment '状态（0正常 1停用）',
  create_by     varchar(64)     default ''                 comment '创建者',
  create_time   datetime                                   comment '创建时间',
  update_by     varchar(64)     default ''			       comment '更新者',
  update_time   datetime                                   comment '更新时间',
  remark        varchar(500)    default null               comment '备注',
  primary key (post_id)
) engine=innodb comment = '岗位信息表';

-- ----------------------------
-- 初始化-岗位信息表数据
-- ----------------------------
insert into sys_post values(1, 'ceo',  '董事长',    1, '0', 'admin', sysdate(), '', null, '');
insert into sys_post values(2, 'se',   '项目经理',  2, '0', 'admin', sysdate(), '', null, '');
insert into sys_post values(3, 'hr',   '人力资源',  3, '0', 'admin', sysdate(), '', null, '');
insert into sys_post values(4, 'user', '普通员工',  4, '0', 'admin', sysdate(), '', null, '');


-- ----------------------------
-- 4、角色信息表
-- ----------------------------
drop table if exists sys_role;
create table sys_role (
  role_id              bigint(20)      not null auto_increment    comment '角色ID',
  role_name            varchar(30)     not null                   comment '角色名称',
  role_key             varchar(100)    not null                   comment '角色权限字符串',
  role_sort            int(4)          not null                   comment '显示顺序',
  data_scope           char(1)         default '1'                comment '数据范围（1：全部数据权限 2：自定数据权限 3：本部门数据权限 4：本部门及以下数据权限）',
  menu_check_strictly  tinyint(1)      default 1                  comment '菜单树选择项是否关联显示',
  dept_check_strictly  tinyint(1)      default 1                  comment '部门树选择项是否关联显示',
  status               char(1)         not null                   comment '角色状态（0正常 1停用）',
  del_flag             char(1)         default '0'                comment '删除标志（0代表存在 2代表删除）',
  create_by            varchar(64)     default ''                 comment '创建者',
  create_time          datetime                                   comment '创建时间',
  update_by            varchar(64)     default ''                 comment '更新者',
  update_time          datetime                                   comment '更新时间',
  remark               varchar(500)    default null               comment '备注',
  primary key (role_id)
) engine=innodb auto_increment=100 comment = '角色信息表';

-- ----------------------------
-- 初始化-角色信息表数据
-- ----------------------------
insert into sys_role values('1', '超级管理员',  'admin',  1, 1, 1, 1, '0', '0', 'admin', sysdate(), '', null, '超级管理员');
insert into sys_role values('2', '普通角色',    'common', 2, 2, 1, 1, '0', '0', 'admin', sysdate(), '', null, '普通角色');


-- ----------------------------
-- 5、菜单权限表
-- ----------------------------
drop table if exists sys_menu;
create table sys_menu (
  menu_id           bigint(20)      not null auto_increment    comment '菜单ID',
  menu_name         varchar(50)     not null                   comment '菜单名称',
  parent_id         bigint(20)      default 0                  comment '父菜单ID',
  order_num         int(4)          default 0                  comment '显示顺序',
  path              varchar(200)    default ''                 comment '路由地址',
  component         varchar(255)    default null               comment '组件路径',
  query             varchar(255)    default null               comment '路由参数',
  is_frame          int(1)          default 1                  comment '是否为外链（0是 1否）',
  is_cache          int(1)          default 0                  comment '是否缓存（0缓存 1不缓存）',
  menu_type         char(1)         default ''                 comment '菜单类型（M目录 C菜单 F按钮）',
  visible           char(1)         default 0                  comment '菜单状态（0显示 1隐藏）',
  status            char(1)         default 0                  comment '菜单状态（0正常 1停用）',
  perms             varchar(100)    default null               comment '权限标识',
  icon              varchar(100)    default '#'                comment '菜单图标',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time       datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  remark            varchar(500)    default ''                 comment '备注',
  primary key (menu_id)
) engine=innodb auto_increment=2000 comment = '菜单权限表';

-- ----------------------------
-- 初始化-菜单信息表数据
-- ----------------------------
-- 一级菜单
insert into sys_menu values('1', '系统管理', '0', '1', 'system',           null, '', 1, 0, 'M', '0', '0', '', 'system',   'admin', sysdate(), '', null, '系统管理目录');
insert into sys_menu values('2', '系统监控', '0', '2', 'monitor',          null, '', 1, 0, 'M', '0', '0', '', 'monitor',  'admin', sysdate(), '', null, '系统监控目录');
insert into sys_menu values('3', '系统工具', '0', '3', 'tool',             null, '', 1, 0, 'M', '0', '0', '', 'tool',     'admin', sysdate(), '', null, '系统工具目录');
insert into sys_menu values('4', '若依官网', '0', '4', 'http://ruoyi.vip', null, '', 0, 0, 'M', '0', '0', '', 'guide',    'admin', sysdate(), '', null, '若依官网地址');
-- 二级菜单
insert into sys_menu values('100',  '用户管理', '1',   '1', 'user',       'system/user/index',        '', 1, 0, 'C', '0', '0', 'system:user:list',        'user',          'admin', sysdate(), '', null, '用户管理菜单');
insert into sys_menu values('101',  '角色管理', '1',   '2', 'role',       'system/role/index',        '', 1, 0, 'C', '0', '0', 'system:role:list',        'peoples',       'admin', sysdate(), '', null, '角色管理菜单');
insert into sys_menu values('102',  '菜单管理', '1',   '3', 'menu',       'system/menu/index',        '', 1, 0, 'C', '0', '0', 'system:menu:list',        'tree-table',    'admin', sysdate(), '', null, '菜单管理菜单');
insert into sys_menu values('103',  '部门管理', '1',   '4', 'dept',       'system/dept/index',        '', 1, 0, 'C', '0', '0', 'system:dept:list',        'tree',          'admin', sysdate(), '', null, '部门管理菜单');
insert into sys_menu values('104',  '岗位管理', '1',   '5', 'post',       'system/post/index',        '', 1, 0, 'C', '0', '0', 'system:post:list',        'post',          'admin', sysdate(), '', null, '岗位管理菜单');
insert into sys_menu values('105',  '字典管理', '1',   '6', 'dict',       'system/dict/index',        '', 1, 0, 'C', '0', '0', 'system:dict:list',        'dict',          'admin', sysdate(), '', null, '字典管理菜单');
insert into sys_menu values('106',  '参数设置', '1',   '7', 'config',     'system/config/index',      '', 1, 0, 'C', '0', '0', 'system:config:list',      'edit',          'admin', sysdate(), '', null, '参数设置菜单');
insert into sys_menu values('107',  '通知公告', '1',   '8', 'notice',     'system/notice/index',      '', 1, 0, 'C', '0', '0', 'system:notice:list',      'message',       'admin', sysdate(), '', null, '通知公告菜单');
insert into sys_menu values('108',  '日志管理', '1',   '9', 'log',        '',                         '', 1, 0, 'M', '0', '0', '',                        'log',           'admin', sysdate(), '', null, '日志管理菜单');
insert into sys_menu values('109',  '在线用户', '2',   '1', 'online',     'monitor/online/index',     '', 1, 0, 'C', '0', '0', 'monitor:online:list',     'online',        'admin', sysdate(), '', null, '在线用户菜单');
insert into sys_menu values('110',  '定时任务', '2',   '2', 'job',        'monitor/job/index',        '', 1, 0, 'C', '0', '0', 'monitor:job:list',        'job',           'admin', sysdate(), '', null, '定时任务菜单');
insert into sys_menu values('111',  '数据监控', '2',   '3', 'druid',      'monitor/druid/index',      '', 1, 0, 'C', '0', '0', 'monitor:druid:list',      'druid',         'admin', sysdate(), '', null, '数据监控菜单');
insert into sys_menu values('112',  '服务监控', '2',   '4', 'server',     'monitor/server/index',     '', 1, 0, 'C', '0', '0', 'monitor:server:list',     'server',        'admin', sysdate(), '', null, '服务监控菜单');
insert into sys_menu values('113',  '缓存监控', '2',   '5', 'cache',      'monitor/cache/index',      '', 1, 0, 'C', '0', '0', 'monitor:cache:list',      'redis',         'admin', sysdate(), '', null, '缓存监控菜单');
insert into sys_menu values('114',  '缓存列表', '2',   '6', 'cacheList',  'monitor/cache/list',       '', 1, 0, 'C', '0', '0', 'monitor:cache:list',      'redis-list',    'admin', sysdate(), '', null, '缓存列表菜单');
insert into sys_menu values('115',  '表单构建', '3',   '1', 'build',      'tool/build/index',         '', 1, 0, 'C', '0', '0', 'tool:build:list',         'build',         'admin', sysdate(), '', null, '表单构建菜单');
insert into sys_menu values('116',  '代码生成', '3',   '2', 'gen',        'tool/gen/index',           '', 1, 0, 'C', '0', '0', 'tool:gen:list',           'code',          'admin', sysdate(), '', null, '代码生成菜单');
insert into sys_menu values('117',  '系统接口', '3',   '3', 'swagger',    'tool/swagger/index',       '', 1, 0, 'C', '0', '0', 'tool:swagger:list',       'swagger',       'admin', sysdate(), '', null, '系统接口菜单');
-- 三级菜单
insert into sys_menu values('500',  '操作日志', '108', '1', 'operlog',    'monitor/operlog/index',    '', 1, 0, 'C', '0', '0', 'monitor:operlog:list',    'form',          'admin', sysdate(), '', null, '操作日志菜单');
insert into sys_menu values('501',  '登录日志', '108', '2', 'logininfor', 'monitor/logininfor/index', '', 1, 0, 'C', '0', '0', 'monitor:logininfor:list', 'logininfor',    'admin', sysdate(), '', null, '登录日志菜单');
-- 用户管理按钮
insert into sys_menu values('1000', '用户查询', '100', '1',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:query',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1001', '用户新增', '100', '2',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:add',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1002', '用户修改', '100', '3',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:edit',           '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1003', '用户删除', '100', '4',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:remove',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1004', '用户导出', '100', '5',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:export',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1005', '用户导入', '100', '6',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:import',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1006', '重置密码', '100', '7',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:resetPwd',       '#', 'admin', sysdate(), '', null, '');
-- 角色管理按钮
insert into sys_menu values('1007', '角色查询', '101', '1',  '', '', '', 1, 0, 'F', '0', '0', 'system:role:query',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1008', '角色新增', '101', '2',  '', '', '', 1, 0, 'F', '0', '0', 'system:role:add',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1009', '角色修改', '101', '3',  '', '', '', 1, 0, 'F', '0', '0', 'system:role:edit',           '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1010', '角色删除', '101', '4',  '', '', '', 1, 0, 'F', '0', '0', 'system:role:remove',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1011', '角色导出', '101', '5',  '', '', '', 1, 0, 'F', '0', '0', 'system:role:export',         '#', 'admin', sysdate(), '', null, '');
-- 菜单管理按钮
insert into sys_menu values('1012', '菜单查询', '102', '1',  '', '', '', 1, 0, 'F', '0', '0', 'system:menu:query',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1013', '菜单新增', '102', '2',  '', '', '', 1, 0, 'F', '0', '0', 'system:menu:add',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1014', '菜单修改', '102', '3',  '', '', '', 1, 0, 'F', '0', '0', 'system:menu:edit',           '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1015', '菜单删除', '102', '4',  '', '', '', 1, 0, 'F', '0', '0', 'system:menu:remove',         '#', 'admin', sysdate(), '', null, '');
-- 部门管理按钮
insert into sys_menu values('1016', '部门查询', '103', '1',  '', '', '', 1, 0, 'F', '0', '0', 'system:dept:query',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1017', '部门新增', '103', '2',  '', '', '', 1, 0, 'F', '0', '0', 'system:dept:add',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1018', '部门修改', '103', '3',  '', '', '', 1, 0, 'F', '0', '0', 'system:dept:edit',           '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1019', '部门删除', '103', '4',  '', '', '', 1, 0, 'F', '0', '0', 'system:dept:remove',         '#', 'admin', sysdate(), '', null, '');
-- 岗位管理按钮
insert into sys_menu values('1020', '岗位查询', '104', '1',  '', '', '', 1, 0, 'F', '0', '0', 'system:post:query',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1021', '岗位新增', '104', '2',  '', '', '', 1, 0, 'F', '0', '0', 'system:post:add',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1022', '岗位修改', '104', '3',  '', '', '', 1, 0, 'F', '0', '0', 'system:post:edit',           '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1023', '岗位删除', '104', '4',  '', '', '', 1, 0, 'F', '0', '0', 'system:post:remove',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1024', '岗位导出', '104', '5',  '', '', '', 1, 0, 'F', '0', '0', 'system:post:export',         '#', 'admin', sysdate(), '', null, '');
-- 字典管理按钮
insert into sys_menu values('1025', '字典查询', '105', '1', '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:query',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1026', '字典新增', '105', '2', '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:add',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1027', '字典修改', '105', '3', '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:edit',           '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1028', '字典删除', '105', '4', '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:remove',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1029', '字典导出', '105', '5', '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:export',         '#', 'admin', sysdate(), '', null, '');
-- 参数设置按钮
insert into sys_menu values('1030', '参数查询', '106', '1', '#', '', '', 1, 0, 'F', '0', '0', 'system:config:query',        '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1031', '参数新增', '106', '2', '#', '', '', 1, 0, 'F', '0', '0', 'system:config:add',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1032', '参数修改', '106', '3', '#', '', '', 1, 0, 'F', '0', '0', 'system:config:edit',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1033', '参数删除', '106', '4', '#', '', '', 1, 0, 'F', '0', '0', 'system:config:remove',       '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1034', '参数导出', '106', '5', '#', '', '', 1, 0, 'F', '0', '0', 'system:config:export',       '#', 'admin', sysdate(), '', null, '');
-- 通知公告按钮
insert into sys_menu values('1035', '公告查询', '107', '1', '#', '', '', 1, 0, 'F', '0', '0', 'system:notice:query',        '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1036', '公告新增', '107', '2', '#', '', '', 1, 0, 'F', '0', '0', 'system:notice:add',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1037', '公告修改', '107', '3', '#', '', '', 1, 0, 'F', '0', '0', 'system:notice:edit',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1038', '公告删除', '107', '4', '#', '', '', 1, 0, 'F', '0', '0', 'system:notice:remove',       '#', 'admin', sysdate(), '', null, '');
-- 操作日志按钮
insert into sys_menu values('1039', '操作查询', '500', '1', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:operlog:query',      '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1040', '操作删除', '500', '2', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:operlog:remove',     '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1041', '日志导出', '500', '3', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:operlog:export',     '#', 'admin', sysdate(), '', null, '');
-- 登录日志按钮
insert into sys_menu values('1042', '登录查询', '501', '1', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:logininfor:query',   '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1043', '登录删除', '501', '2', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:logininfor:remove',  '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1044', '日志导出', '501', '3', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:logininfor:export',  '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1045', '账户解锁', '501', '4', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:logininfor:unlock',  '#', 'admin', sysdate(), '', null, '');
-- 在线用户按钮
insert into sys_menu values('1046', '在线查询', '109', '1', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:online:query',       '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1047', '批量强退', '109', '2', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:online:batchLogout', '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1048', '单条强退', '109', '3', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:online:forceLogout', '#', 'admin', sysdate(), '', null, '');
-- 定时任务按钮
insert into sys_menu values('1049', '任务查询', '110', '1', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:job:query',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1050', '任务新增', '110', '2', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:job:add',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1051', '任务修改', '110', '3', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:job:edit',           '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1052', '任务删除', '110', '4', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:job:remove',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1053', '状态修改', '110', '5', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:job:changeStatus',   '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1054', '任务导出', '110', '6', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:job:export',         '#', 'admin', sysdate(), '', null, '');
-- 代码生成按钮
insert into sys_menu values('1055', '生成查询', '116', '1', '#', '', '', 1, 0, 'F', '0', '0', 'tool:gen:query',             '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1056', '生成修改', '116', '2', '#', '', '', 1, 0, 'F', '0', '0', 'tool:gen:edit',              '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1057', '生成删除', '116', '3', '#', '', '', 1, 0, 'F', '0', '0', 'tool:gen:remove',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1058', '导入代码', '116', '4', '#', '', '', 1, 0, 'F', '0', '0', 'tool:gen:import',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1059', '预览代码', '116', '5', '#', '', '', 1, 0, 'F', '0', '0', 'tool:gen:preview',           '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1060', '生成代码', '116', '6', '#', '', '', 1, 0, 'F', '0', '0', 'tool:gen:code',              '#', 'admin', sysdate(), '', null, '');


-- ----------------------------
-- 6、用户和角色关联表  用户N-1角色
-- ----------------------------
drop table if exists sys_user_role;
create table sys_user_role (
  user_id   bigint(20) not null comment '用户ID',
  role_id   bigint(20) not null comment '角色ID',
  primary key(user_id, role_id)
) engine=innodb comment = '用户和角色关联表';

-- ----------------------------
-- 初始化-用户和角色关联表数据
-- ----------------------------
insert into sys_user_role values ('1', '1');
insert into sys_user_role values ('2', '2');


-- ----------------------------
-- 7、角色和菜单关联表  角色1-N菜单
-- ----------------------------
drop table if exists sys_role_menu;
create table sys_role_menu (
  role_id   bigint(20) not null comment '角色ID',
  menu_id   bigint(20) not null comment '菜单ID',
  primary key(role_id, menu_id)
) engine=innodb comment = '角色和菜单关联表';

-- ----------------------------
-- 初始化-角色和菜单关联表数据
-- ----------------------------
insert into sys_role_menu values ('2', '1');
insert into sys_role_menu values ('2', '2');
insert into sys_role_menu values ('2', '3');
insert into sys_role_menu values ('2', '4');
insert into sys_role_menu values ('2', '100');
insert into sys_role_menu values ('2', '101');
insert into sys_role_menu values ('2', '102');
insert into sys_role_menu values ('2', '103');
insert into sys_role_menu values ('2', '104');
insert into sys_role_menu values ('2', '105');
insert into sys_role_menu values ('2', '106');
insert into sys_role_menu values ('2', '107');
insert into sys_role_menu values ('2', '108');
insert into sys_role_menu values ('2', '109');
insert into sys_role_menu values ('2', '110');
insert into sys_role_menu values ('2', '111');
insert into sys_role_menu values ('2', '112');
insert into sys_role_menu values ('2', '113');
insert into sys_role_menu values ('2', '114');
insert into sys_role_menu values ('2', '115');
insert into sys_role_menu values ('2', '116');
insert into sys_role_menu values ('2', '117');
insert into sys_role_menu values ('2', '500');
insert into sys_role_menu values ('2', '501');
insert into sys_role_menu values ('2', '1000');
insert into sys_role_menu values ('2', '1001');
insert into sys_role_menu values ('2', '1002');
insert into sys_role_menu values ('2', '1003');
insert into sys_role_menu values ('2', '1004');
insert into sys_role_menu values ('2', '1005');
insert into sys_role_menu values ('2', '1006');
insert into sys_role_menu values ('2', '1007');
insert into sys_role_menu values ('2', '1008');
insert into sys_role_menu values ('2', '1009');
insert into sys_role_menu values ('2', '1010');
insert into sys_role_menu values ('2', '1011');
insert into sys_role_menu values ('2', '1012');
insert into sys_role_menu values ('2', '1013');
insert into sys_role_menu values ('2', '1014');
insert into sys_role_menu values ('2', '1015');
insert into sys_role_menu values ('2', '1016');
insert into sys_role_menu values ('2', '1017');
insert into sys_role_menu values ('2', '1018');
insert into sys_role_menu values ('2', '1019');
insert into sys_role_menu values ('2', '1020');
insert into sys_role_menu values ('2', '1021');
insert into sys_role_menu values ('2', '1022');
insert into sys_role_menu values ('2', '1023');
insert into sys_role_menu values ('2', '1024');
insert into sys_role_menu values ('2', '1025');
insert into sys_role_menu values ('2', '1026');
insert into sys_role_menu values ('2', '1027');
insert into sys_role_menu values ('2', '1028');
insert into sys_role_menu values ('2', '1029');
insert into sys_role_menu values ('2', '1030');
insert into sys_role_menu values ('2', '1031');
insert into sys_role_menu values ('2', '1032');
insert into sys_role_menu values ('2', '1033');
insert into sys_role_menu values ('2', '1034');
insert into sys_role_menu values ('2', '1035');
insert into sys_role_menu values ('2', '1036');
insert into sys_role_menu values ('2', '1037');
insert into sys_role_menu values ('2', '1038');
insert into sys_role_menu values ('2', '1039');
insert into sys_role_menu values ('2', '1040');
insert into sys_role_menu values ('2', '1041');
insert into sys_role_menu values ('2', '1042');
insert into sys_role_menu values ('2', '1043');
insert into sys_role_menu values ('2', '1044');
insert into sys_role_menu values ('2', '1045');
insert into sys_role_menu values ('2', '1046');
insert into sys_role_menu values ('2', '1047');
insert into sys_role_menu values ('2', '1048');
insert into sys_role_menu values ('2', '1049');
insert into sys_role_menu values ('2', '1050');
insert into sys_role_menu values ('2', '1051');
insert into sys_role_menu values ('2', '1052');
insert into sys_role_menu values ('2', '1053');
insert into sys_role_menu values ('2', '1054');
insert into sys_role_menu values ('2', '1055');
insert into sys_role_menu values ('2', '1056');
insert into sys_role_menu values ('2', '1057');
insert into sys_role_menu values ('2', '1058');
insert into sys_role_menu values ('2', '1059');
insert into sys_role_menu values ('2', '1060');

-- ----------------------------
-- 8、角色和部门关联表  角色1-N部门
-- ----------------------------
drop table if exists sys_role_dept;
create table sys_role_dept (
  role_id   bigint(20) not null comment '角色ID',
  dept_id   bigint(20) not null comment '部门ID',
  primary key(role_id, dept_id)
) engine=innodb comment = '角色和部门关联表';

-- ----------------------------
-- 初始化-角色和部门关联表数据
-- ----------------------------
insert into sys_role_dept values ('2', '100');
insert into sys_role_dept values ('2', '101');
insert into sys_role_dept values ('2', '105');


-- ----------------------------
-- 9、用户与岗位关联表  用户1-N岗位
-- ----------------------------
drop table if exists sys_user_post;
create table sys_user_post
(
  user_id   bigint(20) not null comment '用户ID',
  post_id   bigint(20) not null comment '岗位ID',
  primary key (user_id, post_id)
) engine=innodb comment = '用户与岗位关联表';

-- ----------------------------
-- 初始化-用户与岗位关联表数据
-- ----------------------------
insert into sys_user_post values ('1', '1');
insert into sys_user_post values ('2', '2');


-- ----------------------------
-- 10、操作日志记录
-- ----------------------------
drop table if exists sys_oper_log;
create table sys_oper_log (
  oper_id           bigint(20)      not null auto_increment    comment '日志主键',
  title             varchar(50)     default ''                 comment '模块标题',
  business_type     int(2)          default 0                  comment '业务类型（0其它 1新增 2修改 3删除）',
  method            varchar(100)    default ''                 comment '方法名称',
  request_method    varchar(10)     default ''                 comment '请求方式',
  operator_type     int(1)          default 0                  comment '操作类别（0其它 1后台用户 2手机端用户）',
  oper_name         varchar(50)     default ''                 comment '操作人员',
  dept_name         varchar(50)     default ''                 comment '部门名称',
  oper_url          varchar(255)    default ''                 comment '请求URL',
  oper_ip           varchar(128)    default ''                 comment '主机地址',
  oper_location     varchar(255)    default ''                 comment '操作地点',
  oper_param        varchar(2000)   default ''                 comment '请求参数',
  json_result       varchar(2000)   default ''                 comment '返回参数',
  status            int(1)          default 0                  comment '操作状态（0正常 1异常）',
  error_msg         varchar(2000)   default ''                 comment '错误消息',
  oper_time         datetime                                   comment '操作时间',
  cost_time         bigint(20)      default 0                  comment '消耗时间',
  primary key (oper_id),
  key idx_sys_oper_log_bt (business_type),
  key idx_sys_oper_log_s  (status),
  key idx_sys_oper_log_ot (oper_time)
) engine=innodb auto_increment=100 comment = '操作日志记录';


-- ----------------------------
-- 11、字典类型表
-- ----------------------------
drop table if exists sys_dict_type;
create table sys_dict_type
(
  dict_id          bigint(20)      not null auto_increment    comment '字典主键',
  dict_name        varchar(100)    default ''                 comment '字典名称',
  dict_type        varchar(100)    default ''                 comment '字典类型',
  status           char(1)         default '0'                comment '状态（0正常 1停用）',
  create_by        varchar(64)     default ''                 comment '创建者',
  create_time      datetime                                   comment '创建时间',
  update_by        varchar(64)     default ''                 comment '更新者',
  update_time      datetime                                   comment '更新时间',
  remark           varchar(500)    default null               comment '备注',
  primary key (dict_id),
  unique (dict_type)
) engine=innodb auto_increment=100 comment = '字典类型表';

insert into sys_dict_type values(1,  '用户性别', 'sys_user_sex',        '0', 'admin', sysdate(), '', null, '用户性别列表');
insert into sys_dict_type values(2,  '菜单状态', 'sys_show_hide',       '0', 'admin', sysdate(), '', null, '菜单状态列表');
insert into sys_dict_type values(3,  '系统开关', 'sys_normal_disable',  '0', 'admin', sysdate(), '', null, '系统开关列表');
insert into sys_dict_type values(4,  '任务状态', 'sys_job_status',      '0', 'admin', sysdate(), '', null, '任务状态列表');
insert into sys_dict_type values(5,  '任务分组', 'sys_job_group',       '0', 'admin', sysdate(), '', null, '任务分组列表');
insert into sys_dict_type values(6,  '系统是否', 'sys_yes_no',          '0', 'admin', sysdate(), '', null, '系统是否列表');
insert into sys_dict_type values(7,  '通知类型', 'sys_notice_type',     '0', 'admin', sysdate(), '', null, '通知类型列表');
insert into sys_dict_type values(8,  '通知状态', 'sys_notice_status',   '0', 'admin', sysdate(), '', null, '通知状态列表');
insert into sys_dict_type values(9,  '操作类型', 'sys_oper_type',       '0', 'admin', sysdate(), '', null, '操作类型列表');
insert into sys_dict_type values(10, '系统状态', 'sys_common_status',   '0', 'admin', sysdate(), '', null, '登录状态列表');


-- ----------------------------
-- 12、字典数据表
-- ----------------------------
drop table if exists sys_dict_data;
create table sys_dict_data
(
  dict_code        bigint(20)      not null auto_increment    comment '字典编码',
  dict_sort        int(4)          default 0                  comment '字典排序',
  dict_label       varchar(100)    default ''                 comment '字典标签',
  dict_value       varchar(100)    default ''                 comment '字典键值',
  dict_type        varchar(100)    default ''                 comment '字典类型',
  css_class        varchar(100)    default null               comment '样式属性（其他样式扩展）',
  list_class       varchar(100)    default null               comment '表格回显样式',
  is_default       char(1)         default 'N'                comment '是否默认（Y是 N否）',
  status           char(1)         default '0'                comment '状态（0正常 1停用）',
  create_by        varchar(64)     default ''                 comment '创建者',
  create_time      datetime                                   comment '创建时间',
  update_by        varchar(64)     default ''                 comment '更新者',
  update_time      datetime                                   comment '更新时间',
  remark           varchar(500)    default null               comment '备注',
  primary key (dict_code)
) engine=innodb auto_increment=100 comment = '字典数据表';

insert into sys_dict_data values(1,  1,  '男',       '0',       'sys_user_sex',        '',   '',        'Y', '0', 'admin', sysdate(), '', null, '性别男');
insert into sys_dict_data values(2,  2,  '女',       '1',       'sys_user_sex',        '',   '',        'N', '0', 'admin', sysdate(), '', null, '性别女');
insert into sys_dict_data values(3,  3,  '未知',     '2',       'sys_user_sex',        '',   '',        'N', '0', 'admin', sysdate(), '', null, '性别未知');
insert into sys_dict_data values(4,  1,  '显示',     '0',       'sys_show_hide',       '',   'primary', 'Y', '0', 'admin', sysdate(), '', null, '显示菜单');
insert into sys_dict_data values(5,  2,  '隐藏',     '1',       'sys_show_hide',       '',   'danger',  'N', '0', 'admin', sysdate(), '', null, '隐藏菜单');
insert into sys_dict_data values(6,  1,  '正常',     '0',       'sys_normal_disable',  '',   'primary', 'Y', '0', 'admin', sysdate(), '', null, '正常状态');
insert into sys_dict_data values(7,  2,  '停用',     '1',       'sys_normal_disable',  '',   'danger',  'N', '0', 'admin', sysdate(), '', null, '停用状态');
insert into sys_dict_data values(8,  1,  '正常',     '0',       'sys_job_status',      '',   'primary', 'Y', '0', 'admin', sysdate(), '', null, '正常状态');
insert into sys_dict_data values(9,  2,  '暂停',     '1',       'sys_job_status',      '',   'danger',  'N', '0', 'admin', sysdate(), '', null, '停用状态');
insert into sys_dict_data values(10, 1,  '默认',     'DEFAULT', 'sys_job_group',       '',   '',        'Y', '0', 'admin', sysdate(), '', null, '默认分组');
insert into sys_dict_data values(11, 2,  '系统',     'SYSTEM',  'sys_job_group',       '',   '',        'N', '0', 'admin', sysdate(), '', null, '系统分组');
insert into sys_dict_data values(12, 1,  '是',       'Y',       'sys_yes_no',          '',   'primary', 'Y', '0', 'admin', sysdate(), '', null, '系统默认是');
insert into sys_dict_data values(13, 2,  '否',       'N',       'sys_yes_no',          '',   'danger',  'N', '0', 'admin', sysdate(), '', null, '系统默认否');
insert into sys_dict_data values(14, 1,  '通知',     '1',       'sys_notice_type',     '',   'warning', 'Y', '0', 'admin', sysdate(), '', null, '通知');
insert into sys_dict_data values(15, 2,  '公告',     '2',       'sys_notice_type',     '',   'success', 'N', '0', 'admin', sysdate(), '', null, '公告');
insert into sys_dict_data values(16, 1,  '正常',     '0',       'sys_notice_status',   '',   'primary', 'Y', '0', 'admin', sysdate(), '', null, '正常状态');
insert into sys_dict_data values(17, 2,  '关闭',     '1',       'sys_notice_status',   '',   'danger',  'N', '0', 'admin', sysdate(), '', null, '关闭状态');
insert into sys_dict_data values(18, 99, '其他',     '0',       'sys_oper_type',       '',   'info',    'N', '0', 'admin', sysdate(), '', null, '其他操作');
insert into sys_dict_data values(19, 1,  '新增',     '1',       'sys_oper_type',       '',   'info',    'N', '0', 'admin', sysdate(), '', null, '新增操作');
insert into sys_dict_data values(20, 2,  '修改',     '2',       'sys_oper_type',       '',   'info',    'N', '0', 'admin', sysdate(), '', null, '修改操作');
insert into sys_dict_data values(21, 3,  '删除',     '3',       'sys_oper_type',       '',   'danger',  'N', '0', 'admin', sysdate(), '', null, '删除操作');
insert into sys_dict_data values(22, 4,  '授权',     '4',       'sys_oper_type',       '',   'primary', 'N', '0', 'admin', sysdate(), '', null, '授权操作');
insert into sys_dict_data values(23, 5,  '导出',     '5',       'sys_oper_type',       '',   'warning', 'N', '0', 'admin', sysdate(), '', null, '导出操作');
insert into sys_dict_data values(24, 6,  '导入',     '6',       'sys_oper_type',       '',   'warning', 'N', '0', 'admin', sysdate(), '', null, '导入操作');
insert into sys_dict_data values(25, 7,  '强退',     '7',       'sys_oper_type',       '',   'danger',  'N', '0', 'admin', sysdate(), '', null, '强退操作');
insert into sys_dict_data values(26, 8,  '生成代码', '8',       'sys_oper_type',       '',   'warning', 'N', '0', 'admin', sysdate(), '', null, '生成操作');
insert into sys_dict_data values(27, 9,  '清空数据', '9',       'sys_oper_type',       '',   'danger',  'N', '0', 'admin', sysdate(), '', null, '清空操作');
insert into sys_dict_data values(28, 1,  '成功',     '0',       'sys_common_status',   '',   'primary', 'N', '0', 'admin', sysdate(), '', null, '正常状态');
insert into sys_dict_data values(29, 2,  '失败',     '1',       'sys_common_status',   '',   'danger',  'N', '0', 'admin', sysdate(), '', null, '停用状态');


-- ----------------------------
-- 13、参数配置表
-- ----------------------------
drop table if exists sys_config;
create table sys_config (
  config_id         int(5)          not null auto_increment    comment '参数主键',
  config_name       varchar(100)    default ''                 comment '参数名称',
  config_key        varchar(100)    default ''                 comment '参数键名',
  config_value      varchar(500)    default ''                 comment '参数键值',
  config_type       char(1)         default 'N'                comment '系统内置（Y是 N否）',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time       datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  remark            varchar(500)    default null               comment '备注',
  primary key (config_id)
) engine=innodb auto_increment=100 comment = '参数配置表';

insert into sys_config values(1, '主框架页-默认皮肤样式名称',     'sys.index.skinName',            'skin-blue',     'Y', 'admin', sysdate(), '', null, '蓝色 skin-blue、绿色 skin-green、紫色 skin-purple、红色 skin-red、黄色 skin-yellow' );
insert into sys_config values(2, '用户管理-账号初始密码',         'sys.user.initPassword',         '123456',        'Y', 'admin', sysdate(), '', null, '初始化密码 123456' );
insert into sys_config values(3, '主框架页-侧边栏主题',           'sys.index.sideTheme',           'theme-dark',    'Y', 'admin', sysdate(), '', null, '深色主题theme-dark，浅色主题theme-light' );
insert into sys_config values(4, '账号自助-验证码开关',           'sys.account.captchaEnabled',    'true',          'Y', 'admin', sysdate(), '', null, '是否开启验证码功能（true开启，false关闭）');
insert into sys_config values(5, '账号自助-是否开启用户注册功能', 'sys.account.registerUser',      'false',         'Y', 'admin', sysdate(), '', null, '是否开启注册用户功能（true开启，false关闭）');
insert into sys_config values(6, '用户登录-黑名单列表',           'sys.login.blackIPList',         '',              'Y', 'admin', sysdate(), '', null, '设置登录IP黑名单限制，多个匹配项以;分隔，支持匹配（*通配、网段）');


-- ----------------------------
-- 14、系统访问记录
-- ----------------------------
drop table if exists sys_logininfor;
create table sys_logininfor (
  info_id        bigint(20)     not null auto_increment   comment '访问ID',
  user_name      varchar(50)    default ''                comment '用户账号',
  ipaddr         varchar(128)   default ''                comment '登录IP地址',
  login_location varchar(255)   default ''                comment '登录地点',
  browser        varchar(50)    default ''                comment '浏览器类型',
  os             varchar(50)    default ''                comment '操作系统',
  status         char(1)        default '0'               comment '登录状态（0成功 1失败）',
  msg            varchar(255)   default ''                comment '提示消息',
  login_time     datetime                                 comment '访问时间',
  primary key (info_id),
  key idx_sys_logininfor_s  (status),
  key idx_sys_logininfor_lt (login_time)
) engine=innodb auto_increment=100 comment = '系统访问记录';


-- ----------------------------
-- 15、定时任务调度表
-- ----------------------------
drop table if exists sys_job;
create table sys_job (
  job_id              bigint(20)    not null auto_increment    comment '任务ID',
  job_name            varchar(64)   default ''                 comment '任务名称',
  job_group           varchar(64)   default 'DEFAULT'          comment '任务组名',
  invoke_target       varchar(500)  not null                   comment '调用目标字符串',
  cron_expression     varchar(255)  default ''                 comment 'cron执行表达式',
  misfire_policy      varchar(20)   default '3'                comment '计划执行错误策略（1立即执行 2执行一次 3放弃执行）',
  concurrent          char(1)       default '1'                comment '是否并发执行（0允许 1禁止）',
  status              char(1)       default '0'                comment '状态（0正常 1暂停）',
  create_by           varchar(64)   default ''                 comment '创建者',
  create_time         datetime                                 comment '创建时间',
  update_by           varchar(64)   default ''                 comment '更新者',
  update_time         datetime                                 comment '更新时间',
  remark              varchar(500)  default ''                 comment '备注信息',
  primary key (job_id, job_name, job_group)
) engine=innodb auto_increment=100 comment = '定时任务调度表';

insert into sys_job values(1, '系统默认（无参）', 'DEFAULT', 'ryTask.ryNoParams',        '0/10 * * * * ?', '3', '1', '1', 'admin', sysdate(), '', null, '');
insert into sys_job values(2, '系统默认（有参）', 'DEFAULT', 'ryTask.ryParams(\'ry\')',  '0/15 * * * * ?', '3', '1', '1', 'admin', sysdate(), '', null, '');
insert into sys_job values(3, '系统默认（多参）', 'DEFAULT', 'ryTask.ryMultipleParams(\'ry\', true, 2000L, 316.50D, 100)',  '0/20 * * * * ?', '3', '1', '1', 'admin', sysdate(), '', null, '');


-- ----------------------------
-- 16、定时任务调度日志表
-- ----------------------------
drop table if exists sys_job_log;
create table sys_job_log (
  job_log_id          bigint(20)     not null auto_increment    comment '任务日志ID',
  job_name            varchar(64)    not null                   comment '任务名称',
  job_group           varchar(64)    not null                   comment '任务组名',
  invoke_target       varchar(500)   not null                   comment '调用目标字符串',
  job_message         varchar(500)                              comment '日志信息',
  status              char(1)        default '0'                comment '执行状态（0正常 1失败）',
  exception_info      varchar(2000)  default ''                 comment '异常信息',
  create_time         datetime                                  comment '创建时间',
  primary key (job_log_id)
) engine=innodb comment = '定时任务调度日志表';


-- ----------------------------
-- 17、通知公告表
-- ----------------------------
drop table if exists sys_notice;
create table sys_notice (
  notice_id         int(4)          not null auto_increment    comment '公告ID',
  notice_title      varchar(50)     not null                   comment '公告标题',
  notice_type       char(1)         not null                   comment '公告类型（1通知 2公告）',
  notice_content    longblob        default null               comment '公告内容',
  status            char(1)         default '0'                comment '公告状态（0正常 1关闭）',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time       datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  remark            varchar(255)    default null               comment '备注',
  primary key (notice_id)
) engine=innodb auto_increment=10 comment = '通知公告表';

-- ----------------------------
-- 初始化-公告信息表数据
-- ----------------------------
insert into sys_notice values('1', '温馨提醒：2018-07-01 若依新版本发布啦', '2', '新版本内容', '0', 'admin', sysdate(), '', null, '管理员');
insert into sys_notice values('2', '维护通知：2018-07-01 若依系统凌晨维护', '1', '维护内容',   '0', 'admin', sysdate(), '', null, '管理员');


-- ----------------------------
-- 18、代码生成业务表
-- ----------------------------
drop table if exists gen_table;
create table gen_table (
  table_id          bigint(20)      not null auto_increment    comment '编号',
  table_name        varchar(200)    default ''                 comment '表名称',
  table_comment     varchar(500)    default ''                 comment '表描述',
  sub_table_name    varchar(64)     default null               comment '关联子表的表名',
  sub_table_fk_name varchar(64)     default null               comment '子表关联的外键名',
  class_name        varchar(100)    default ''                 comment '实体类名称',
  tpl_category      varchar(200)    default 'crud'             comment '使用的模板（crud单表操作 tree树表操作）',
  package_name      varchar(100)                               comment '生成包路径',
  module_name       varchar(30)                                comment '生成模块名',
  business_name     varchar(30)                                comment '生成业务名',
  function_name     varchar(50)                                comment '生成功能名',
  function_author   varchar(50)                                comment '生成功能作者',
  gen_type          char(1)         default '0'                comment '生成代码方式（0zip压缩包 1自定义路径）',
  gen_path          varchar(200)    default '/'                comment '生成路径（不填默认项目路径）',
  options           varchar(1000)                              comment '其它生成选项',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time 	    datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  remark            varchar(500)    default null               comment '备注',
  primary key (table_id)
) engine=innodb auto_increment=1 comment = '代码生成业务表';


-- ----------------------------
-- 19、代码生成业务表字段
-- ----------------------------
drop table if exists gen_table_column;
create table gen_table_column (
  column_id         bigint(20)      not null auto_increment    comment '编号',
  table_id          varchar(64)                                comment '归属表编号',
  column_name       varchar(200)                               comment '列名称',
  column_comment    varchar(500)                               comment '列描述',
  column_type       varchar(100)                               comment '列类型',
  java_type         varchar(500)                               comment 'JAVA类型',
  java_field        varchar(200)                               comment 'JAVA字段名',
  is_pk             char(1)                                    comment '是否主键（1是）',
  is_increment      char(1)                                    comment '是否自增（1是）',
  is_required       char(1)                                    comment '是否必填（1是）',
  is_insert         char(1)                                    comment '是否为插入字段（1是）',
  is_edit           char(1)                                    comment '是否编辑字段（1是）',
  is_list           char(1)                                    comment '是否列表字段（1是）',
  is_query          char(1)                                    comment '是否查询字段（1是）',
  query_type        varchar(200)    default 'EQ'               comment '查询方式（等于、不等于、大于、小于、范围）',
  html_type         varchar(200)                               comment '显示类型（文本框、文本域、下拉框、复选框、单选框、日期控件）',
  dict_type         varchar(200)    default ''                 comment '字典类型',
  sort              int                                        comment '排序',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time 	    datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  primary key (column_id)
) engine=innodb auto_increment=1 comment = '代码生成业务表字段';





---------------------------------------------------------------------------------------------------------------

-- ----------------------------
-- 20、指令性工作清单管理
-- ----------------------------
DROP TABLE
    IF
    EXISTS t_command_work_bill;
CREATE TABLE t_command_work_bill (
                                     id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                     receipt_date datetime COMMENT '收文日期',
                                     file_name VARCHAR ( 255 ) COMMENT '文件名称',
                                     command_work VARCHAR ( 255 ) COMMENT '指令工作',
                                     implementation_measure VARCHAR ( 255 ) COMMENT '落实措施',
                                     implementation_deadline datetime COMMENT '落实期限',
                                     responsible_organization VARCHAR ( 255 ) COMMENT '责任单位',
                                     principal VARCHAR ( 64 ) COMMENT '责任人',
                                     implementation_status VARCHAR ( 64 ) COMMENT '落实情况',
                                     create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                     create_time datetime COMMENT '创建时间',
                                     update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                     update_time datetime COMMENT '更新时间',
                                     remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                                     PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '指令性工作清单管理';

-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('指令性工作清单管理', '2000', '1', 'TCommandWorkBill', 'DirectiveTask/TCommandWorkBill/index', 1, 0, 'C', '0', '0', 'DirectiveTask:TCommandWorkBill:list', '#', 'admin', sysdate(), '', null, '指令性工作清单管理菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('指令性工作清单管理查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'DirectiveTask:TCommandWorkBill:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('指令性工作清单管理新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'DirectiveTask:TCommandWorkBill:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('指令性工作清单管理修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'DirectiveTask:TCommandWorkBill:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('指令性工作清单管理删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'DirectiveTask:TCommandWorkBill:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('指令性工作清单管理导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'DirectiveTask:TCommandWorkBill:export',       '#', 'admin', sysdate(), '', null, '');



-- ----------------------------
-- 20、第一本账单
-- ----------------------------

DROP TABLE
    IF
    EXISTS t_work_plan;
CREATE TABLE t_work_plan (
                             id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                             word_plan VARCHAR ( 255 ) COMMENT '工作记录',
                             planned_completion_time datetime COMMENT '计划完成时间',
                             existing_problem VARCHAR ( 255 ) COMMENT '存在问题',
                             countermeasure VARCHAR ( 255 ) COMMENT '对策措施',
                             resolution_time_limit VARCHAR ( 255 ) COMMENT '解决时限',
                             responsible_organization VARCHAR ( 255 ) COMMENT '责任单位',
                             principal VARCHAR ( 64 ) COMMENT '责任人',
                             create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                             create_time datetime COMMENT '创建时间',
                             update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                             update_time datetime COMMENT '更新时间',
                             remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                             PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '工作计划一本账';

-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('工作计划一本账', '2019', '1', 'TWorkPlan', 'Invoice/TWorkPlan/index', 1, 0, 'C', '0', '0', 'Invoice:TWorkPlan:list', '#', 'admin', sysdate(), '', null, '工作计划一本账菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('工作计划一本账查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TWorkPlan:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('工作计划一本账新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TWorkPlan:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('工作计划一本账修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TWorkPlan:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('工作计划一本账删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TWorkPlan:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('工作计划一本账导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TWorkPlan:export',       '#', 'admin', sysdate(), '', null, '');


DROP TABLE
    IF
    EXISTS t_prepare_war;
CREATE TABLE t_prepare_war (
                               id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                               concrete_issue VARCHAR ( 255 ) COMMENT '具体问题',
                               solution VARCHAR ( 255 ) COMMENT '解决措施',
                               responsible_organization VARCHAR ( 255 ) COMMENT '责任单位',
                               principal VARCHAR ( 64 ) COMMENT '责任人',
                               resolution_time_limit VARCHAR ( 255 ) COMMENT '解决时限',
                               standard_request VARCHAR ( 255 ) COMMENT '标准要求',
                               billing_time datetime COMMENT '挂账时间',
                               create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                               create_time datetime COMMENT '创建时间',
                               update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                               update_time datetime COMMENT '更新时间',
                               remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                               PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '备战打仗一本账';

-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('备战打仗一本账', '2019', '1', 'TPrepareWar', 'Invoice/TPrepareWar/index', 1, 0, 'C', '0', '0', 'Invoice:TPrepareWar:list', '#', 'admin', sysdate(), '', null, '备战打仗一本账菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('备战打仗一本账查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TPrepareWar:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('备战打仗一本账新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TPrepareWar:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('备战打仗一本账修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TPrepareWar:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('备战打仗一本账删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TPrepareWar:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('备战打仗一本账导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TPrepareWar:export',       '#', 'admin', sysdate(), '', null, '');


DROP TABLE
    IF
    EXISTS t_equipment_quality;
CREATE TABLE t_equipment_quality (
                                     id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                     date_time datetime COMMENT '日期',
                                     equipment_type VARCHAR ( 255 ) COMMENT '装备型号',
                                     major VARCHAR ( 255 ) COMMENT '专业',
                                     quick_facts VARCHAR ( 255 ) COMMENT '简要情况',
                                     reasons VARCHAR ( 255 ) COMMENT '问题原因',
                                     countermeasure VARCHAR ( 255 ) COMMENT '对策措施',
                                     principal VARCHAR ( 64 ) COMMENT '责任人',
                                     follow_up VARCHAR ( 255 ) COMMENT '跟进情况',
                                     return_zero VARCHAR ( 255 ) COMMENT '归零情况',
                                     brief_report VARCHAR ( 255 ) COMMENT '简报',
                                     create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                     create_time datetime COMMENT '创建时间',
                                     update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                     update_time datetime COMMENT '更新时间',
                                     remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                                     PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '装备质量一本账';


-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('装备质量一本账', '2019', '1', 'TEquipmentQuality', 'Invoice/TEquipmentQuality/index', 1, 0, 'C', '0', '0', 'Invoice:TEquipmentQuality:list', '#', 'admin', sysdate(), '', null, '装备质量一本账菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('装备质量一本账查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TEquipmentQuality:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('装备质量一本账新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TEquipmentQuality:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('装备质量一本账修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TEquipmentQuality:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('装备质量一本账删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TEquipmentQuality:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('装备质量一本账导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TEquipmentQuality:export',       '#', 'admin', sysdate(), '', null, '');

DROP TABLE
    IF
    EXISTS t_troop_problem;
CREATE TABLE t_troop_problem (
                                 id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                 date_time datetime COMMENT '时间',
                                 organization VARCHAR ( 255 ) COMMENT '单位',
                                 contacts VARCHAR ( 255 ) COMMENT '联系人',
                                 issue VARCHAR ( 255 ) COMMENT '具体问题',
                                 solution VARCHAR ( 255 ) COMMENT '解决措施',
                                 responsible_organization VARCHAR ( 255 ) COMMENT '责任单位',
                                 principal VARCHAR ( 64 ) COMMENT '责任人',
                                 resolution_time_limit VARCHAR ( 255 ) COMMENT '解决时限',
                                 Completion_situation VARCHAR ( 255 ) COMMENT '完成情况',
                                 create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                 create_time datetime COMMENT '创建时间',
                                 update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                 update_time datetime COMMENT '更新时间',
                                 remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                                 PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '部队问题一本账';

-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('部队问题一本账', '2019', '1', 'TTroopProblem', 'Invoice/TTroopProblem/index', 1, 0, 'C', '0', '0', 'Invoice:TTroopProblem:list', '#', 'admin', sysdate(), '', null, '部队问题一本账菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('部队问题一本账查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TTroopProblem:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('部队问题一本账新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TTroopProblem:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('部队问题一本账修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TTroopProblem:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('部队问题一本账删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TTroopProblem:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('部队问题一本账导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Invoice:TTroopProblem:export',       '#', 'admin', sysdate(), '', null, '');


DROP TABLE
    IF
    EXISTS t_today_in_history;
CREATE TABLE t_today_in_history (
                                    id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                    date_time datetime COMMENT '时间',
                                    aircraft_type VARCHAR ( 255 ) COMMENT '机型',
                                    occurrence_time datetime COMMENT '发生时间',
                                    problem_description VARCHAR ( 255 ) COMMENT '问题描述',
                                    category VARCHAR ( 255 ) COMMENT '类别',
                                    classify VARCHAR ( 255 ) COMMENT '分类',
                                    consequence VARCHAR ( 255 ) COMMENT '后果',
                                    quality VARCHAR ( 255 ) COMMENT '性质',
                                    remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                                    photo_path VARCHAR ( 255 ) COMMENT '照片',
                                    create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                    create_time datetime COMMENT '创建时间',
                                    update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                    update_time datetime COMMENT '更新时间',
                                    PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '历史上的今天';

-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('历史上的今天', '2049', '1', 'TTodayInHistory', 'Security/TTodayInHistory/index', 1, 0, 'C', '0', '0', 'Security:TTodayInHistory:list', '#', 'admin', sysdate(), '', null, '历史上的今天菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('历史上的今天查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Security:TTodayInHistory:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('历史上的今天新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Security:TTodayInHistory:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('历史上的今天修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Security:TTodayInHistory:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('历史上的今天删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Security:TTodayInHistory:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('历史上的今天导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Security:TTodayInHistory:export',       '#', 'admin', sysdate(), '', null, '');


DROP TABLE
    IF
    EXISTS t_safety_inspection;
CREATE TABLE t_safety_inspection (
                                     id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                     organization VARCHAR ( 255 ) COMMENT '单位',
                                     date_time datetime COMMENT '日期',
                                     major VARCHAR ( 255 ) COMMENT '专业',
                                     issue_details VARCHAR ( 255 ) COMMENT '问题详情',
                                     principal VARCHAR ( 64 ) COMMENT '责任人',
                                     superviser VARCHAR ( 64 ) COMMENT '检查人',
                                     rectification_measures VARCHAR ( 255 ) COMMENT '整改措施',
                                     classify VARCHAR ( 255 ) COMMENT '分类',
                                     rectification_status VARCHAR ( 255 ) COMMENT '整改情况',
                                     remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                                     create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                     create_time datetime COMMENT '创建时间',
                                     update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                     update_time datetime COMMENT '更新时间',
                                     PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '安全检查信息';

-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('安全检查信息', '2049', '1', 'TSafetyInspection', 'Security/TSafetyInspection/index', 1, 0, 'C', '0', '0', 'Security:TSafetyInspection:list', '#', 'admin', sysdate(), '', null, '安全检查信息菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('安全检查信息查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Security:TSafetyInspection:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('安全检查信息新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Security:TSafetyInspection:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('安全检查信息修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Security:TSafetyInspection:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('安全检查信息删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Security:TSafetyInspection:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('安全检查信息导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Security:TSafetyInspection:export',       '#', 'admin', sysdate(), '', null, '');


DROP TABLE
    IF
    EXISTS t_disclaimer_report;
CREATE TABLE t_disclaimer_report (
                                     id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                     organization_1st VARCHAR ( 255 ) COMMENT '第一单位',
                                     organization_2nd VARCHAR ( 255 ) COMMENT '第二单位',
                                     organization_3rd VARCHAR ( 255 ) COMMENT '第三单位',
                                     occurrence_date datetime COMMENT '事件发生时间',
                                     occurrence_place VARCHAR ( 255 ) COMMENT '事件发生地点',
                                     Occurrence_time VARCHAR ( 255 ) COMMENT '事件发生时机',
                                     reporter_position_category VARCHAR ( 255 ) COMMENT '报告人岗位类别',
                                     reporter_position_character VARCHAR ( 255 ) COMMENT '报告人岗位角色',
                                     aircraft_type VARCHAR ( 255 ) COMMENT '机型',
                                     reporter_name VARCHAR ( 255 ) COMMENT '报告人姓名',
                                     reporter_phone VARCHAR ( 255 ) COMMENT '报告人电话',
                                     cause_classification VARCHAR ( 255 ) COMMENT '原因分类',
                                     event_type VARCHAR ( 255 ) COMMENT '类型',
                                     Event_itle VARCHAR ( 255 ) COMMENT '事件标题',
                                     event_roperty VARCHAR ( 255 ) COMMENT '事件性质',
                                     event_course VARCHAR ( 255 ) COMMENT '事件经过',
                                     Analysis_preventive_measures VARCHAR ( 255 ) COMMENT '事件分析及预防措施',
                                     principal_post VARCHAR ( 255 ) COMMENT '旅团站负责人职务',
                                     principal_name VARCHAR ( 255 ) COMMENT '旅团站负责人姓名',
                                     remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                                     photo_path VARCHAR ( 255 ) COMMENT '照片',
                                     create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                     create_time datetime COMMENT '创建时间',
                                     update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                     update_time datetime COMMENT '更新时间',
                                     PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '免责报告';


-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('免责报告', '2049', '1', 'TDisclaimerReport', 'Security/TDisclaimerReport/index', 1, 0, 'C', '0', '0', 'Security:TDisclaimerReport:list', '#', 'admin', sysdate(), '', null, '免责报告菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('免责报告查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Security:TDisclaimerReport:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('免责报告新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Security:TDisclaimerReport:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('免责报告修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Security:TDisclaimerReport:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('免责报告删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Security:TDisclaimerReport:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('免责报告导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Security:TDisclaimerReport:export',       '#', 'admin', sysdate(), '', null, '');

DROP TABLE
    IF
    EXISTS t_safety_reward;
CREATE TABLE t_safety_reward (
                                 id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                 declaration_date datetime COMMENT '申报时间',
                                 declaration_name VARCHAR ( 255 ) COMMENT '姓名',
                                 declaration_type VARCHAR ( 255 ) COMMENT '奖项',
                                 declaration_reply VARCHAR ( 255 ) COMMENT '批复',
                                 to_receive VARCHAR ( 255 ) COMMENT '是否领取',
                                 remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                                 create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                 create_time datetime COMMENT '创建时间',
                                 update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                 update_time datetime COMMENT '更新时间',
                                 PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '安全奖惩信息';

-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('安全奖惩信息', '2049', '1', 'TSafetyReward', 'Security/TSafetyReward/index', 1, 0, 'C', '0', '0', 'Security:TSafetyReward:list', '#', 'admin', sysdate(), '', null, '安全奖惩信息菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('安全奖惩信息查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Security:TSafetyReward:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('安全奖惩信息新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Security:TSafetyReward:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('安全奖惩信息修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Security:TSafetyReward:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('安全奖惩信息删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Security:TSafetyReward:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('安全奖惩信息导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Security:TSafetyReward:export',       '#', 'admin', sysdate(), '', null, '');



DROP TABLE
    IF
    EXISTS t_briefing_fault_information;
CREATE TABLE t_briefing_fault_information (
                                              id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                              year datetime COMMENT '年份',
                                              cause VARCHAR ( 255 ) COMMENT '原因（R/N)',
                                              date datetime COMMENT '日期',
                                              war_zone VARCHAR ( 255 ) COMMENT '战区',
                                              military_counsellor VARCHAR ( 255 ) COMMENT '军师',
                                              war_brigade VARCHAR ( 255 ) COMMENT '旅团',
                                              aircraft_type VARCHAR ( 255 ) COMMENT '机型',
                                              brief_overview VARCHAR ( 255 ) COMMENT '简要经过',
                                              question_cause VARCHAR ( 255 ) COMMENT '问题原因',
                                              solution_measures VARCHAR ( 255 ) COMMENT '解决措施',
                                              investigation_punishment VARCHAR ( 255 ) COMMENT '查处进展',
                                              brief_period VARCHAR ( 255 ) COMMENT '简报期数',
                                              professional_involvement VARCHAR ( 255 ) COMMENT '涉及专业',
                                              type VARCHAR ( 255 ) COMMENT '类型',
                                              superior_requirements VARCHAR ( 255 ) COMMENT '上级要求',
                                              remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                                              create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                              create_time datetime COMMENT '创建时间',
                                              update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                              update_time datetime COMMENT '更新时间',
                                              PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '简报故障信息管理';

-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('简报故障信息管理', '2093', '1', 'TBriefingFaultInformation', 'Fault/TBriefingFaultInformation/index', 1, 0, 'C', '0', '0', 'Fault:TBriefingFaultInformation:list', '#', 'admin', sysdate(), '', null, '简报故障信息管理菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('简报故障信息管理查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Fault:TBriefingFaultInformation:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('简报故障信息管理新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Fault:TBriefingFaultInformation:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('简报故障信息管理修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Fault:TBriefingFaultInformation:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('简报故障信息管理删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Fault:TBriefingFaultInformation:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('简报故障信息管理导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Fault:TBriefingFaultInformation:export',       '#', 'admin', sysdate(), '', null, '');

DROP TABLE
    IF
    EXISTS t_aircraft_failure;
CREATE TABLE t_aircraft_failure (
                                    id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                    aircraft_id VARCHAR ( 255 ) COMMENT '机号',
                                    failure_datetime datetime COMMENT '故障时间',
                                    failure_moment VARCHAR ( 255 ) COMMENT '故障时机',
                                    failure_pnenomenon VARCHAR ( 255 ) COMMENT '故障现象',
                                    failure_cause VARCHAR ( 255 ) COMMENT '故障原因',
                                    disposal_measures VARCHAR ( 255 ) COMMENT '处置措施',
                                    product_model VARCHAR ( 255 ) COMMENT '产品型号',
                                    product_system VARCHAR ( 255 ) COMMENT '所属系统',
                                    remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                                    create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                    create_time datetime COMMENT '创建时间',
                                    update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                    update_time datetime COMMENT '更新时间',
                                    PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '飞机故障及缺陷管理';

-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('飞机故障及缺陷管理', '2093', '1', 'TAircraftFailure', 'Fault/TAircraftFailure/index', 1, 0, 'C', '0', '0', 'Fault:TAircraftFailure:list', '#', 'admin', sysdate(), '', null, '飞机故障及缺陷管理菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('飞机故障及缺陷管理查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Fault:TAircraftFailure:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('飞机故障及缺陷管理新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Fault:TAircraftFailure:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('飞机故障及缺陷管理修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Fault:TAircraftFailure:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('飞机故障及缺陷管理删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Fault:TAircraftFailure:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('飞机故障及缺陷管理导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Fault:TAircraftFailure:export',       '#', 'admin', sysdate(), '', null, '');

DROP TABLE
    IF
    EXISTS t_technical_bulletin;
CREATE TABLE t_technical_bulletin (
                                      id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                      bulletin_id VARCHAR ( 255 ) COMMENT '通报编号',
                                      factory_id VARCHAR ( 255 ) COMMENT '工厂编号',
                                      bulletin_name VARCHAR ( 255 ) COMMENT '通报名称',
                                      aircraft_type VARCHAR ( 255 ) COMMENT '机型',
                                      major VARCHAR ( 255 ) COMMENT '专业',
                                      Scope_involvement VARCHAR ( 255 ) COMMENT '涉及范围',
                                      receipt_date datetime COMMENT '收文日期',
                                      implementation_deadline datetime COMMENT '落实期限',
                                      implementation_way VARCHAR ( 255 ) COMMENT '落实方式',
                                      implementation_opportunity VARCHAR ( 255 ) COMMENT '落实时机',
                                      finish_date datetime COMMENT '完成日期',
                                      place_on_file VARCHAR ( 255 ) COMMENT '是否归档',
                                      technology_id VARCHAR ( 255 ) COMMENT '对应技术更改单号',
                                      Expiration_control VARCHAR ( 255 ) COMMENT '到期控制',
                                      remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                                      create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                      create_time datetime COMMENT '创建时间',
                                      update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                      update_time datetime COMMENT '更新时间',
                                      PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '技术通报管理模块';

-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术通报管理模块', '2094', '1', 'TTechnicalBulletin', 'Technology/TTechnicalBulletin/index', 1, 0, 'C', '0', '0', 'Technology:TTechnicalBulletin:list', '#', 'admin', sysdate(), '', null, '技术通报管理模块菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术通报管理模块查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TTechnicalBulletin:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术通报管理模块新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TTechnicalBulletin:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术通报管理模块修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TTechnicalBulletin:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术通报管理模块删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TTechnicalBulletin:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术通报管理模块导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TTechnicalBulletin:export',       '#', 'admin', sysdate(), '', null, '');


DROP TABLE
    IF
    EXISTS t_technical_changes;
CREATE TABLE t_technical_changes (
                                     id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                     ratify_id VARCHAR ( 255 ) COMMENT '批准单号',
                                     apply_for_id VARCHAR ( 255 ) COMMENT '申请单号',
                                     update_name VARCHAR ( 255 ) COMMENT '更改名称',
                                     Scope_involvement VARCHAR ( 255 ) COMMENT '涉及范围',
                                     major VARCHAR ( 255 ) COMMENT '专业',
                                     implementation_deadline datetime COMMENT '落实期限',
                                     implementation_opportunity VARCHAR ( 255 ) COMMENT '落实时机',
                                     place_on_file VARCHAR ( 255 ) COMMENT '是否归档',
                                     Expiration_control VARCHAR ( 255 ) COMMENT '到期控制',
                                     num_21 VARCHAR ( 255 ) COMMENT '21',
                                     num_22 VARCHAR ( 255 ) COMMENT '22',
                                     num_23 VARCHAR ( 255 ) COMMENT '23',
                                     num_24 VARCHAR ( 255 ) COMMENT '24',
                                     num_25 VARCHAR ( 255 ) COMMENT '25',
                                     num_26 VARCHAR ( 255 ) COMMENT '26',
                                     num_27 VARCHAR ( 255 ) COMMENT '27',
                                     remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                                     create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                     create_time datetime COMMENT '创建时间',
                                     update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                     update_time datetime COMMENT '更新时间',
                                     PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '技术更改单管理模块';


-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术更改单管理模块', '2094', '1', 'TTechnicalChanges', 'Technology/TTechnicalChanges/index', 1, 0, 'C', '0', '0', 'Technology:TTechnicalChanges:list', '#', 'admin', sysdate(), '', null, '技术更改单管理模块菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术更改单管理模块查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TTechnicalChanges:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术更改单管理模块新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TTechnicalChanges:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术更改单管理模块修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TTechnicalChanges:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术更改单管理模块删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TTechnicalChanges:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术更改单管理模块导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TTechnicalChanges:export',       '#', 'admin', sysdate(), '', null, '');


DROP TABLE
    IF
    EXISTS t_software_version;
CREATE TABLE t_software_version (
                                    id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                    Software_resident_device VARCHAR ( 255 ) COMMENT '软件驻留设备',
                                    model VARCHAR ( 255 ) COMMENT '型号',
                                    software_name VARCHAR ( 255 ) COMMENT '软件名称',
                                    software_version VARCHAR ( 255 ) COMMENT '版本',
                                    remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                                    create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                    create_time datetime COMMENT '创建时间',
                                    update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                    update_time datetime COMMENT '更新时间',
                                    PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '软件版本管理模块';

-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('软件版本管理模块', '2094', '1', 'TSoftwareVersion', 'Technology/TSoftwareVersion/index', 1, 0, 'C', '0', '0', 'Technology:TSoftwareVersion:list', '#', 'admin', sysdate(), '', null, '软件版本管理模块菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('软件版本管理模块查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TSoftwareVersion:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('软件版本管理模块新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TSoftwareVersion:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('软件版本管理模块修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TSoftwareVersion:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('软件版本管理模块删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TSoftwareVersion:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('软件版本管理模块导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TSoftwareVersion:export',       '#', 'admin', sysdate(), '', null, '');


DROP TABLE
    IF
    EXISTS t_memorandum_management;
CREATE TABLE t_memorandum_management (
                                         id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                         aircraft_type VARCHAR ( 255 ) COMMENT '机型',
                                         aircraft_id VARCHAR ( 255 ) COMMENT '飞机号',
                                         exfactory_id VARCHAR ( 255 ) COMMENT '出厂编号',
                                         memorandum_id VARCHAR ( 255 ) COMMENT '备忘录编号',
                                         update_object VARCHAR ( 255 ) COMMENT '更改对象',
                                         responsible_organization VARCHAR ( 255 ) COMMENT '责任单位',
                                         implementation_deadline datetime COMMENT '落实期限',
                                         major VARCHAR ( 255 ) COMMENT '专业',
                                         resume_date datetime COMMENT '履历本完成日期',
                                         fly_date datetime COMMENT '成飞完成日期',
                                         if_overdue VARCHAR ( 255 ) COMMENT '是否超期',
                                         remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                                         create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                         create_time datetime COMMENT '创建时间',
                                         update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                         update_time datetime COMMENT '更新时间',
                                         PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '备忘录管理模块';

-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('备忘录管理模块', '2094', '1', 'TMemorandumManagement', 'Technology/TMemorandumManagement/index', 1, 0, 'C', '0', '0', 'Technology:TMemorandumManagement:list', '#', 'admin', sysdate(), '', null, '备忘录管理模块菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('备忘录管理模块查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TMemorandumManagement:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('备忘录管理模块新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TMemorandumManagement:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('备忘录管理模块修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TMemorandumManagement:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('备忘录管理模块删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TMemorandumManagement:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('备忘录管理模块导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Technology:TMemorandumManagement:export',       '#', 'admin', sysdate(), '', null, '');


DROP TABLE
    IF
    EXISTS t_assessment_result;
CREATE TABLE t_assessment_result (
                                     id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                     assessment_name VARCHAR ( 255 ) COMMENT '姓名',
                                     assessment_organization VARCHAR ( 255 ) COMMENT '单位',
                                     aircraft_type VARCHAR ( 255 ) COMMENT '机型',
                                     major VARCHAR ( 255 ) COMMENT '专业',
                                     if_exam VARCHAR ( 255 ) COMMENT '是否参考',
                                     exam_category VARCHAR ( 255 ) COMMENT '参考科目',
                                     exam_level VARCHAR ( 255 ) COMMENT '参考层级',
                                     exam_score VARCHAR ( 255 ) COMMENT '业务',
                                     remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                                     create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                     create_time datetime COMMENT '创建时间',
                                     update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                     update_time datetime COMMENT '更新时间',
                                     PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '考核结果管理';


-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('考核结果管理', '2080', '1', 'TAssessmentResult', 'Train/TAssessmentResult/index', 1, 0, 'C', '0', '0', 'Train:TAssessmentResult:list', '#', 'admin', sysdate(), '', null, '考核结果管理菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('考核结果管理查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Train:TAssessmentResult:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('考核结果管理新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Train:TAssessmentResult:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('考核结果管理修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Train:TAssessmentResult:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('考核结果管理删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Train:TAssessmentResult:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('考核结果管理导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Train:TAssessmentResult:export',       '#', 'admin', sysdate(), '', null, '');



DROP TABLE
    IF
    EXISTS t_training_management;
CREATE TABLE t_training_management (
                                       id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                       assessment_name VARCHAR ( 255 ) COMMENT '姓名',
                                       assessment_organization VARCHAR ( 255 ) COMMENT '单位',
                                       major VARCHAR ( 255 ) COMMENT '专业',
                                       work_category VARCHAR ( 255 ) COMMENT '工作类别(师、代理师、员外)',
                                       ladingbill_date datetime COMMENT '放单日期',
                                       remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                                       create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                       create_time datetime COMMENT '创建时间',
                                       update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                       update_time datetime COMMENT '更新时间',
                                       PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '人员训练技术档案管理';

-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('人员训练技术档案管理', '2080', '1', 'TTrainingManagement', 'Train/TTrainingManagement/index', 1, 0, 'C', '0', '0', 'Train:TTrainingManagement:list', '#', 'admin', sysdate(), '', null, '人员训练技术档案管理菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('人员训练技术档案管理查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Train:TTrainingManagement:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('人员训练技术档案管理新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Train:TTrainingManagement:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('人员训练技术档案管理修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Train:TTrainingManagement:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('人员训练技术档案管理删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Train:TTrainingManagement:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('人员训练技术档案管理导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Train:TTrainingManagement:export',       '#', 'admin', sysdate(), '', null, '');


DROP TABLE
    IF
    EXISTS t_electronic_document;
CREATE TABLE t_electronic_document (
                                       id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                       document_date datetime COMMENT '收文年份',
                                       document_id VARCHAR ( 255 ) COMMENT '收文编号',
                                       document_unit VARCHAR ( 255 ) COMMENT '发文单位',
                                       file_id VARCHAR ( 255 ) COMMENT '文件编号',
                                       file_name VARCHAR ( 255 ) COMMENT '文件名称',
                                       undertake_date datetime COMMENT '承办日期',
                                       undertake_name varchar(255) COMMENT '承办人',
                                       instruction_work VARCHAR ( 255 ) COMMENT '文件中的指令性工作',
                                       leader_reply VARCHAR ( 255 ) COMMENT '领导批示和要求',
                                       head_name varchar(255) COMMENT '负责人',
                                       place_on_file VARCHAR ( 255 ) COMMENT '是否归档',
                                       file_address VARCHAR ( 255 ) COMMENT '存放位置',
                                       create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                       create_time datetime COMMENT '创建时间',
                                       update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                       update_time datetime COMMENT '更新时间',
                                       remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注',
                                       PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '电子文件管理';

-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('电子文件管理', '2131', '1', 'TElectronicDocument', 'Technicaldata/TElectronicDocument/index', 1, 0, 'C', '0', '0', 'Technicaldata:TElectronicDocument:list', '#', 'admin', sysdate(), '', null, '电子文件管理菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('电子文件管理查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Technicaldata:TElectronicDocument:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('电子文件管理新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Technicaldata:TElectronicDocument:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('电子文件管理修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Technicaldata:TElectronicDocument:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('电子文件管理删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Technicaldata:TElectronicDocument:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('电子文件管理导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Technicaldata:TElectronicDocument:export',       '#', 'admin', sysdate(), '', null, '');

DROP TABLE
    IF
    EXISTS t_technical_data;
CREATE TABLE t_technical_data (
                                  id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                  aircraft_type VARCHAR ( 255 ) COMMENT '机型',
                                  book_name varchar(255) COMMENT '书籍名称',
                                  secret_level varchar(255) COMMENT '密级',
                                  publish_unit VARCHAR ( 255 ) COMMENT '出版单位',
                                  publish_date datetime COMMENT '发行日期',
                                  document_id VARCHAR ( 255 ) COMMENT '资料编号',
                                  secret_id VARCHAR ( 255 ) COMMENT '保密编号',
                                  file_address VARCHAR ( 255 ) COMMENT '存放位置',
                                  handover_record VARCHAR ( 255 ) COMMENT '交接记录',
                                  create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                  create_time datetime COMMENT '创建时间',
                                  update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                  update_time datetime COMMENT '更新时间',
                                  remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注（来源，更改）',
                                  PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '技术资料管理';


-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术资料管理', '2131', '1', 'TTechnicalData', 'Technicaldata/TTechnicalData/index', 1, 0, 'C', '0', '0', 'Technicaldata:TTechnicalData:list', '#', 'admin', sysdate(), '', null, '技术资料管理菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术资料管理查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Technicaldata:TTechnicalData:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术资料管理新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Technicaldata:TTechnicalData:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术资料管理修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Technicaldata:TTechnicalData:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术资料管理删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Technicaldata:TTechnicalData:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('技术资料管理导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Technicaldata:TTechnicalData:export',       '#', 'admin', sysdate(), '', null, '');


DROP TABLE
    IF
    EXISTS t_engine_handover;
CREATE TABLE t_engine_handover (
                                   id BIGINT ( 20 ) NOT NULL auto_increment COMMENT '编号',
                                   enginehandover_date datetime COMMENT '日期',
                                   enginehandover_cause datetime COMMENT '原因',
                                   engine_id VARCHAR ( 255 ) COMMENT '发动机号',
                                   put_out VARCHAR ( 255 ) COMMENT '入库/出库',
                                   undertake_name varchar(255) COMMENT '承办人',
                                   if_receive varchar(255) COMMENT '交接清单是否收到',
                                   receive_name varchar(255) COMMENT '交接清单接收人',
                                   create_by VARCHAR ( 64 ) DEFAULT '' COMMENT '创建者',
                                   create_time datetime COMMENT '创建时间',
                                   update_by VARCHAR ( 64 ) DEFAULT '' COMMENT '更新者',
                                   update_time datetime COMMENT '更新时间',
                                   remark VARCHAR ( 500 ) DEFAULT NULL COMMENT '备注（来源，更改）',
                                   PRIMARY KEY ( id )
) ENGINE = INNODB COMMENT = '发动机交接管理';

-- 菜单 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('发动机交接管理', '2131', '1', 'TEngineHandover', 'Technicaldata/TEngineHandover/index', 1, 0, 'C', '0', '0', 'Technicaldata:TEngineHandover:list', '#', 'admin', sysdate(), '', null, '发动机交接管理菜单');

-- 按钮父菜单ID
SELECT @parentId := LAST_INSERT_ID();

-- 按钮 SQL
insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('发动机交接管理查询', @parentId, '1',  '#', '', 1, 0, 'F', '0', '0', 'Technicaldata:TEngineHandover:query',        '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('发动机交接管理新增', @parentId, '2',  '#', '', 1, 0, 'F', '0', '0', 'Technicaldata:TEngineHandover:add',          '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('发动机交接管理修改', @parentId, '3',  '#', '', 1, 0, 'F', '0', '0', 'Technicaldata:TEngineHandover:edit',         '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('发动机交接管理删除', @parentId, '4',  '#', '', 1, 0, 'F', '0', '0', 'Technicaldata:TEngineHandover:remove',       '#', 'admin', sysdate(), '', null, '');

insert into sys_menu (menu_name, parent_id, order_num, path, component, is_frame, is_cache, menu_type, visible, status, perms, icon, create_by, create_time, update_by, update_time, remark)
values('发动机交接管理导出', @parentId, '5',  '#', '', 1, 0, 'F', '0', '0', 'Technicaldata:TEngineHandover:export',       '#', 'admin', sysdate(), '', null, '');